@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -43,25 +43,24 @@ function action_charger_plugin_dist() {
 		if (is_array($syndic_plug = @unserialize($GLOBALS['meta']['syndic_plug'])))
 			foreach ($syndic_plug as $url => $c)
 				essaie_ajouter_liste_plugins($url);
-	} else if ($arg == 'supprimer_flux'
-	AND $url = _request('supprimer_flux')) {
+	} 
+	elseif ($arg == 'supprimer_flux' AND $url = _request('supprimer_flux')) {
 		$syndic_plug = @unserialize($GLOBALS['meta']['syndic_plug']);
 		unset($syndic_plug[$url]);
 		ecrire_meta('syndic_plug', serialize($syndic_plug));
 	}
 
-	if (!preg_match(',^(https?|ftp)://.*\.zip,',
-		$zip = _request('url_zip_plugin'))
-	AND !preg_match(',^(https?|ftp)://.*\.zip,',
-		$zip = _request('url_zip_plugin2')))
+	if (!preg_match(',^(https?|ftp)://.*\.zip,', $zip = $arg)
+		AND !preg_match(',^(https?|ftp)://.*\.zip,', $zip = _request('url_zip_plugin'))
+	  AND !preg_match(',^(https?|ftp)://.*\.zip,', $zip = _request('url_zip_plugin2')))
 	{
 		essaie_ajouter_liste_plugins($zip);
 		include_spip('inc/headers');
-		redirige_url_ecrire('admin_plugin');
+		redirige_url_ecrire('charger_plugin');
 	}
 
 	## si ici on n'est pas en POST c'est qu'il y a un loup
-	if (!$_POST) die('pas en POST ?');
+	//if (!$_POST) die('pas en POST ?');
 
 	# Si definie a '', le chargeur est interdit ; mais on n'aurait de toutes
 	# facons jamais pu venir ici avec toutes les securisations faites :^)
@@ -145,6 +144,7 @@ function action_charger_plugin_dist() {
 					. $retour;
 
 			if (_request('extract')) {
+				$afficher = charger_fonction('afficher_plugin','plugins'); // pour plugin_propre
 				$texte = plugin_propre(
 				spip_xml_aplatit($arbre['plugin'][0]['description']));
 				$texte .= '<p>'._T('plugin_zip_installe_finie',array('zip'=>$zip)).'</p>';
@@ -192,12 +192,14 @@ function action_charger_plugin_dist() {
 	// par defaut on revient sur la page admin_plugin
 	if($redirect == _DIR_RESTREINT OR $redirect == "./"){
 		$redirect_annul = generer_url_ecrire('admin_plugin');
-		$redirect_form = 'admin_plugin&'.$type.'='.preg_replace(',^[^/]+/|/$,', '', $status['dirname']);
+		$redirect_form = 'admin_plugin&voir=recents&'.$type.'='.preg_replace(',^[^/]+/|/$,', '', $status['dirname']);
 		$redirect_action = '';
 	}
 	else{
 		$redirect_annul = $redirect;
 		$redirect_form = preg_replace(',^.*exec\=,', '', $redirect);
+		if (!$suite)
+			$texte .= form_hidden(parametre_url(generer_url_ecrire($redirect_form), $type,preg_replace(',^[^/]+/|/$,', '', $status['dirname'])));
 		$redirect_action = $redirect_form;
 	}
 	echo minipres($retour." ",
