@@ -88,7 +88,17 @@ function insert_breve($id_rubrique) {
 			'data' => $champs
 		)
 	);
-	return sql_insertq("spip_breves", $champs);
+	$id_breve = sql_insertq("spip_breves", $champs);
+	pipeline('post_insertion',
+		array(
+			'args' => array(
+				'table' => 'spip_breves',
+				'id_objet' => $id_breve
+			),
+			'data' => $champs
+		)
+	);
+	return $id_breve;
 }
 
 
@@ -176,6 +186,13 @@ function revisions_breves ($id_breve, $c=false) {
 	include_spip('inc/rubriques');
 	calculer_rubriques_if($id_rubrique, $champs, $statut_ancien);
 
+	// Notifications
+	if ($notifications = charger_fonction('notifications', 'inc')) {
+		$notifications('instituerbreve', $id_breve,
+			array('statut' => $statut, 'statut_ancien' => $statut_ancien)
+		);
+	}
+
 }
 
 // http://doc.spip.org/@revisions_breves_langue
