@@ -65,91 +65,72 @@ function balise_FORMULAIRE__dyn($form)
 	// deux moyen d'arriver ici : 
 	// soit #FORMULAIRE_XX reroute avec 'FORMULAIRE_XX' ajoute en premier arg
 	// soit #FORMULAIRE_{xx}
-		
+
 	// recuperer les arguments passes a la balise
 	// on enleve le premier qui est le nom de la balise 
 	// deja recupere ci-dessus
 
 	$args = func_get_args();
 	array_shift($args);
+	return array("formulaires/$form", 3600, balise_FORMULAIRE__contexte($form, $args));
+}
 
+function balise_FORMULAIRE__contexte($form, $args)
+{
 	// tester si ce formulaire vient d'etre poste (memes arguments)
 	// pour ne pas confondre 2 #FORMULAIRES_XX identiques sur une meme page
+	// si poste, on recupere les erreurs
+
 	$je_suis_poste = false;
 	if ($post_form = _request('formulaire_action')
-	AND ($post_args = _request('formulaire_action_args'))
-	AND is_array($post_args = decoder_contexte_ajax($post_args,$post_form))) {
+	 AND $p = _request('formulaire_action_args')
+	 AND is_array($p = decoder_contexte_ajax($p, $post_form))) {
 		// enlever le faux attribut de langue masque
-		array_shift($post_args);
-		if ($args === $post_args){
+		array_shift($p);
+		if ($args === $p)
 			$je_suis_poste = true;
-		}
 	}
 
-	// init
-	$erreurs = $valeurs = array();
-	$message_ok = $message_erreur = "";
 	$editable = true;
-
-	// si le formulaire vient d'etre poste, on recupere les erreurs
-	if ($je_suis_poste){
+	$erreurs = $post = array();
+	if ($je_suis_poste) {
 		$post = traiter_formulaires_dynamiques(true);
-		$erreurs = isset($post["erreurs_$form"])?$post["erreurs_$form"]:array();
-		$message_ok = "";
-		if (isset($post["message_ok_$form"]))
-			$message_ok = $post["message_ok_$form"];
-		elseif(isset($erreurs['message_ok']))
-			$message_ok = $erreurs["message_ok"];
-		$message_erreur = isset($erreurs['message_erreur'])?$erreurs['message_erreur']:"";
-		$editable = (!isset($post["erreurs_$form"])) || count($erreurs) || 
-			(isset($post["editable_$form"]) && $post["editable_$form"]);
+		$e = "erreurs_$form";
+		$erreurs = isset($post[$e]) ? $post[$e] : array();
+		$editable = "editable_$form";
+		$editable = (!isset($post[$e]))
+			  || count($erreurs)
+			  || (isset($post[$editable]) && $post[$editable]);
 	}
 
-	if ($charger_valeurs = charger_fonction("charger","formulaires/$form/",true))
-		$valeurs = call_user_func_array($charger_valeurs,$args);
-	$valeurs = pipeline(
-		'formulaire_charger',
-		array(
-			'args'=>array('form'=>$form,'args'=>$args,'je_suis_poste'=>$je_suis_poste),
-			'data'=>$valeurs)
-	);
-	
+	$valeurs = formulaire__charger($form, $args, $je_suis_poste);
+
 	// si $valeurs n'est pas un tableau, le formulaire n'est pas applicable
 	// C'est plus fort qu'editable qui est gere par le squelette 
 	// Idealement $valeur doit etre alors un message explicatif.
 	if (!is_array($valeurs)) return is_string($valeurs) ? $valeurs : '';
 	
-	// reperer les valeurs particulieres editable, message_ok et message_erreur
-	if (isset($valeurs['editable'])){
-		$editable = $valeurs['editable'];
-		unset($valeurs['editable']);
-	}
-	foreach(array('message_ok','message_erreur') as $k){
-		if (isset($valeurs[$k])){
-			if (!$je_suis_poste) $$k = $valeurs[$k];
-			unset($valeurs[$k]);
-		}
-	}
-	
 	// charger peut passer une action si le formulaire ne tourne pas sur self()
 	// ou une action vide si elle ne sert pas
-	$action = isset($valeurs['action'])?$valeurs['action']:self();
+	$action = (isset($valeurs['action'])) ? $valeurs['action'] : self('&amp;', true);
 	// bug IEx : si action finit par / 
 	// IE croit que le <form ... action=../ > est autoferme
-	if (substr($action,-1)=='/')
-		$action .= (_SPIP_SCRIPT?_SPIP_SCRIPT:"index.php");
+	if (substr($action,-1)=='/') {
+		// on ajoute une ancre pour feinter IE, au pire ca tue l'ancre qui finit par un /
+		$action .= '#';
+	}
 
 	// recuperer la saisie en cours si erreurs
 	// seulement si c'est ce formulaire qui est poste
 	// ou si on le demande explicitement par le parametre _forcer_request = true
+	$dispo = ($je_suis_poste || (isset($valeurs['_forcer_request']) && $valeurs['_forcer_request']));
 	foreach(array_keys($valeurs) as $champ){
-		if (substr($champ,0,1)!=='_'){
-			if ($je_suis_poste || (isset($valeurs['_forcer_request']) && $valeurs['_forcer_request'])) {
-						if (($v = _request($champ))!==NULL)
-							$valeurs[$champ] = $v;
-			}
+		if ($champ[0]!=='_' AND !in_array($champ, array('message_ok','message_erreur','editable'))) {
+			if ($dispo AND (($v = _request($champ))!==NULL))
+				$valeurs[$champ] = $v;
 			if ($action)
-				$action = parametre_url($action,$champ,''); // nettoyer l'url des champs qui vont etre saisis
+				$action = parametre_url($action,$champ,'');
+			// nettoyer l'url des champs qui vont etre saisis
 			// proteger les ' et les " dans les champs que l'on va injecter
 			$valeurs[$champ] = protege_champ($valeurs[$champ]);
 		}
@@ -168,27 +149,49 @@ function balise_FORMULAIRE__dyn($form)
 		"<input type='hidden' name='arg' value='".$secu['arg']."' />"
 		. "<input type='hidden' name='hash' value='".$secu['hash']."' />";
 	}
-	
+
 	// empiler la lang en tant que premier argument implicite du CVT
 	// pour permettre de la restaurer au moment du Verifier et du Traiter
 	array_unshift($args, $GLOBALS['spip_lang']);
 
-	return array("formulaires/$form",
-		3600,
-		array_merge(
-			$valeurs,
-			array(
-			'form' => $form,
-			'action' => $action,
-			'formulaire_args' => encoder_contexte_ajax($args,$form),
-			'id' => isset($valeurs['id'])?$valeurs['id']:'new',
-			'erreurs' => $erreurs,
-			'message_ok' => $message_ok,
-			'message_erreur' => $message_erreur,
-			'editable' => $editable?' ':'',
-			)
-		)
-	);
+	$valeurs['formulaire_args'] = encoder_contexte_ajax($args, $form);
+	$valeurs['erreurs'] = $erreurs;
+	$valeurs['action'] = $action;
+	$valeurs['form'] = $form;
+
+	if (!isset($valeurs['id'])) $valeurs['id'] = 'new';
+	// editable peut venir de charger() ou de traiter() sinon
+	if (!isset($valeurs['editable'])) $valeurs['editable'] = $editable;
+	// dans tous les cas, renvoyer un espace ou vide (et pas un booleen)
+	$valeurs['editable'] = ($valeurs['editable']?' ':'');
+
+	if ($je_suis_poste) {
+		$valeurs['message_erreur'] = "";
+		if (isset($erreurs['message_erreur']))
+			$valeurs['message_erreur'] = $erreurs['message_erreur'];
+
+		$valeurs['message_ok'] = "";
+		if (isset($post["message_ok_$form"]))
+			$valeurs['message_ok'] = $post["message_ok_$form"];
+		elseif (isset($erreurs['message_ok']))
+			$valeurs['message_ok'] = $erreurs["message_ok"];
+	}
+	
+	return $valeurs;
 }
 
+function formulaire__charger($form, $args, $poste)
+{
+	if ($charger_valeurs = charger_fonction("charger","formulaires/$form",true))
+		$valeurs = call_user_func_array($charger_valeurs,$args);
+	else $valeurs = array();
+
+	$valeurs = pipeline(
+		'formulaire_charger',
+		array(
+			'args'=>array('form'=>$form,'args'=>$args,'je_suis_poste'=>$poste),
+			'data'=>$valeurs)
+	);
+	return $valeurs;
+}
 ?>
