@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -29,7 +29,7 @@ function balise_FORMULAIRE_INSCRIPTION ($p) {
 // [(#FORMULAIRE_INSCRIPTION{nom_inscription, #ID_RUBRIQUE})]
 
 // http://doc.spip.org/@balise_FORMULAIRE_INSCRIPTION_stat
-function balise_FORMULAIRE_INSCRIPTION_stat($args, $filtres) {
+function balise_FORMULAIRE_INSCRIPTION_stat($args, $context_compil) {
 	list($mode, $id, $focus) = $args;
 	$mode = tester_config($id, $mode);
 	return $mode ? array($mode, $focus, $id) : '';
