@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -21,15 +21,16 @@ function balise_FORMULAIRE_SITE ($p) {
 }
 
 // http://doc.spip.org/@balise_FORMULAIRE_SITE_stat
-function balise_FORMULAIRE_SITE_stat($args, $filtres) {
-
-	// Pas d'id_rubrique ? Erreur de squelette
-	if (!$args[0])
-		return erreur_squelette(
-			_T('zbug_champ_hors_motif',
-				array ('champ' => '#FORMULAIRE_SITE',
-					'motif' => 'RUBRIQUES')), '');
+function balise_FORMULAIRE_SITE_stat($args, $context_compil) {
 
+	// Pas d'id_rubrique ? Erreur de contexte
+	if (!$args[0]) {
+		$msg = array('zbug_champ_hors_motif',
+				array ('champ' => 'FORMULAIRE_SITE',
+					'motif' => 'RUBRIQUES'));
+		erreur_squelette($msg, $context_compil);
+		return '';
+	}
 	// Verifier que les visisteurs sont autorises a proposer un site
 
 	return (($GLOBALS['meta']["proposer_sites"] != 2) ? '' : $args);
