@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -18,7 +18,7 @@ function balise_URL_LOGOUT ($p) {return calculer_balise_dynamique($p,'URL_LOGOUT
 
 // $args[0] = url destination apres logout [(#URL_LOGOUT{url})]
 // http://doc.spip.org/@balise_URL_LOGOUT_stat
-function balise_URL_LOGOUT_stat ($args, $filtres) {
+function balise_URL_LOGOUT_stat ($args, $context_compil) {
 	return array($args[0]);
 }
 
