@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -36,8 +36,18 @@ function base_trouver_table_dist($nom, $serveur=''){
 	if (!spip_connect($serveur)
 	OR !preg_match('/^[a-zA-Z0-9._-]*/',$nom))
 		return null;
+
+	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+
+	// le nom du cache depend du serveur mais aussi du nom de la db et du prefixe
+	// ce qui permet une auto invalidation en cas de modif manuelle du fichier
+	// de connexion, et tout risque d'ambiguite
 	if (!isset($nom_cache_desc_sql[$serveur]))
-		$nom_cache_desc_sql[$serveur] = _DIR_CACHE . 'sql_desc' . ($serveur ? '_'.md5($serveur):'') . '.txt';
+		$nom_cache_desc_sql[$serveur] =
+		  _DIR_CACHE . 'sql_desc_'
+		  . ($serveur ? "$serveur_":"")
+		  . substr(md5($connexion['db'].":".$connexion['prefixe']),0,8)
+			.'.txt';
 
 	// un appel avec $nom vide est une demande explicite de vidange du cache des descriptions
 	if (!$nom){
@@ -53,46 +63,53 @@ function base_trouver_table_dist($nom, $serveur=''){
 		$nom_sql = $nom;
 
 	$desc = '';
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
 
-	// base sous SPIP: gerer les abreviations des noms de table
+	// base sous SPIP: gerer les abreviations explicites des noms de table
 	if ($connexion['spip_connect_version']) {
 		include_spip('public/interfaces');
 		if (isset($table_des_tables[$nom])) {
 			$nom = $table_des_tables[$nom];
 			$nom_sql = 'spip_' . $nom;
 		}
-		if (!isset($connexion['tables'][$nom_sql])) {
-			include_spip('base/serial');
-			if (isset($tables_principales[$nom_sql]))
-				$fdesc = $tables_principales[$nom_sql];
-			else {
-				include_spip('base/auxiliaires');
-				if (isset($tables_auxiliaires['spip_' .$nom])) {
-					$nom_sql = 'spip_' . $nom;
-					$fdesc = $tables_auxiliaires[$nom_sql];
-				}  # table locale a cote de SPIP, comme non SPIP:
-			}
-		}
 	}
 
 	// si c'est la premiere table qu'on cherche
 	// et si on est pas explicitement en recalcul
 	// on essaye de recharger le cache des decriptions de ce serveur
 	// dans le fichier cache
-	if (!isset($connexion['tables'][$nom_sql])
+	if (!isset($connexion['tables'][$nom])
 	  AND $GLOBALS['var_mode']!=='recalcul'
 	  AND (!isset($connexion['tables']) OR !$connexion['tables'])) {
 		if (lire_fichier($nom_cache_desc_sql[$serveur],$desc_cache)
 		  AND $desc_cache=unserialize($desc_cache))
 		  $connexion['tables'] = $desc_cache;
 	}
-	if (!isset($connexion['tables'][$nom_sql])) {
+	if (!isset($connexion['tables'][$nom])) {
+		include_spip('base/serial');
+
+		if (isset($tables_principales[$nom_sql]))
+			$fdesc = $tables_principales[$nom_sql];
+		// meme si pas d'abreviation declaree, trouver la table spip_$nom
+		// si c'est une table principale,
+		// puisqu'on le fait aussi pour les tables auxiliaires
+		elseif ($nom_sql==$nom AND isset($tables_principales['spip_' .$nom])){
+			$nom_sql = 'spip_' . $nom;
+			$fdesc = &$tables_principales[$nom_sql];
+		}
+		else {
+			include_spip('base/auxiliaires');
+			if (isset($tables_auxiliaires['spip_' .$nom])) {
+				$nom_sql = 'spip_' . $nom;
+				$fdesc = &$tables_auxiliaires[$nom_sql];
+			}  # table locale a cote de SPIP, comme non SPIP:
+		}
+
+		// faut il interpreter le prefixe 'spip_' ?
+		$transposer_spip = ($nom_sql != $nom);
 		
 		// La *vraie* base a la priorite
 		if (true /*  !$bdesc OR !$bdesc['field']  */) {
-			$t = ($nom_sql != $nom);
-			$desc = sql_showtable($nom_sql, $t, $serveur);
+			$desc = sql_showtable($nom_sql, $transposer_spip, $serveur);
 			if (!$desc OR !$desc['field']) {
 				if (!$fdesc) {
 					spip_log("trouver_table: table inconnue '$serveur' '$nom'");
@@ -110,17 +127,22 @@ function base_trouver_table_dist($nom, $serveur=''){
 			$desc['key']['PRIMARY KEY'] = array_shift(array_keys($desc['field']));
 
 		$desc['table']= $nom_sql;
-		$desc['id_table']= $nom;
 		$desc['connexion']= $serveur;
-		$desc['titre'] = isset($GLOBALS['table_titre'][$nom])
-		? $GLOBALS['table_titre'][$nom] : '';
-		$connexion['tables'][$nom_sql] = $desc;
+		// objet_type peut provoquer un appel reentrant ici.
+		// pour ne pas faire de boucle infinie, on stocke ce qu'on a deja trouve
+		$connexion['tables'][$nom] = $desc;
+
+		$table = table_objet(objet_type($nom));
+		$desc['titre'] =
+		  isset($GLOBALS['table_titre'][$table]) ? $GLOBALS['table_titre'][$table] : '';
+		$connexion['tables'][$nom] = $desc;
 		// une nouvelle table a ete descrite
 		// mettons donc a jour le cache des descriptions de ce serveur
 		if (is_writeable(_DIR_CACHE))
 			ecrire_fichier($nom_cache_desc_sql[$serveur],serialize($connexion['tables']));
 	}
 
-	return $connexion['tables'][$nom_sql];
+	$connexion['tables'][$nom]['id_table']=$nom;
+	return $connexion['tables'][$nom];
 }
 ?>
