@@ -12,18 +12,20 @@
 
 if (!defined("_ECRIRE_INC_VERSION")) return;
 
-// iso latin 9 - Turc <alexis@nds.k12.tr>
+// iso latin 15 - Gaetan Ryckeboer <gryckeboer@virtual-net.fr>
 
 load_charset('iso-8859-1');
 
 $trans = $GLOBALS['CHARSET']['iso-8859-1'];
-$trans[240]=287; //gbreve
-$trans[208]=286; //Gbreve
-$trans[221]=304; //Idot
-$trans[253]=305; //inodot
-$trans[254]=351; //scedil
-$trans[222]=350; //Scedil
+$trans[164]=8364;
+$trans[166]=352;
+$trans[168]=353;
+$trans[180]=381;
+$trans[184]=382;
+$trans[188]=338;
+$trans[189]=339;
+$trans[190]=376;
 
-$GLOBALS['CHARSET']['iso-8859-9'] = $trans;
+$GLOBALS['CHARSET']['iso-8859-15'] = $trans;
 
 ?>
