@@ -30,12 +30,12 @@ function exec_admin_plugin_dist($retour='') {
 	// et l'installation des qu'on est dans la colonne principale
 	// si jamais la liste des plugins actifs change, il faut faire un refresh du hit
 	// pour etre sur que les bons fichiers seront charges lors de l'install
-	if (actualise_plugins_actifs()==-1){
+	if (actualise_plugins_actifs()==-1 AND _request('actualise')<2){
 		include_spip('inc/headers');
-		redirige_par_entete(self());
+		redirige_par_entete(parametre_url(self(),'actualise',_request('actualise')+1,'&'));
 	}
 
-	if (isset($GLOBALS['meta']['plugin_erreur_activation'])){
+	if ($erreur_activation = isset($GLOBALS['meta']['plugin_erreur_activation'])){
 		$erreur_activation = $GLOBALS['meta']['plugin_erreur_activation'];
 		// l'effacement reel de la meta se fera au moment de l'affichage
 		// mais on la vide pour ne pas l'afficher dans le bandeau haut
@@ -122,17 +122,16 @@ function exec_admin_plugin_dist($retour='') {
 	."' />"
 	. "</div>";
 
-
 	$no_button = false;
 
 	// la liste
 	if ($quoi=='actifs'){
 		$aff = affiche_les_plugins($lcpa, $lcpa, $format);
 		$no_button = !strlen($aff);
-		$corps .= $aff;
+		$corps = $aff;
 	}
 	elseif ($quoi=='tous')
-		$corps .= affiche_les_plugins($lpf, $lcpa, $format);
+		$corps = affiche_les_plugins($lpf, $lcpa, $format);
 	else {
 		$dir_auto = substr(_DIR_PLUGINS_AUTO, strlen(_DIR_PLUGINS));
 		$lcpaffiche = array();
@@ -143,8 +142,7 @@ function exec_admin_plugin_dist($retour='') {
 			OR in_array($f, $plugins_interessants))
 				$lcpaffiche[] = $f;
 
-		$corps .= affiche_les_plugins($lcpaffiche, $lcpa, $format);
-
+		$corps = affiche_les_plugins($lcpaffiche, $lcpa, $format);
 	}
 
 	if (!$no_button)
