@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -47,7 +47,6 @@ function exec_config_fonctions_dist()
 	$previsualiseur = charger_fonction('previsualiseur', 'configuration');
 	$relayeur = charger_fonction('relayeur', 'configuration');
 	$type_urls = charger_fonction('type_urls', 'configuration');
-	$compresseur = charger_fonction('compresseur', 'configuration');
 
 	echo 
 
@@ -67,8 +66,6 @@ function exec_config_fonctions_dist()
 
 	  $type_urls(), // Choix de type_urls
 
-	  $compresseur(), // Compression http et compactages CSS ou JS
-
 	'';
 
 	//
