@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -501,7 +501,7 @@ function liste_archive_jointe($valables, $zip, $type, $id, $mode, $id_document,
 		. fin_block()
 
 
-		. "<div style='text-align: right;'><input class='fondo spip_xx-small' type='submit' value='".
+		. "<div style='text-align: right;'><input type='submit' value='".
 		_T('bouton_valider').
 		  "' />";
 
