@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -24,8 +24,14 @@ define('_ADMINS_RESTREINTS', true);
 define('_STATUT_AUTEUR_CREATION', '1comite');
 // statuts associables a des rubriques (separes par des virgules)
 define('_STATUT_AUTEUR_RUBRIQUE', _ADMINS_RESTREINTS ? '0minirezo' : '');
-// id du ou des webmestres, '1:5:90' a regler dans mes_options
-if (!defined ('_ID_WEBMESTRES')) define ('_ID_WEBMESTRES', '1');
+
+
+// mes_fonctions peut aussi declarer des autorisations, donc il faut donc le charger
+if ($f = find_in_path('mes_fonctions.php')) {
+	global $dossier_squelettes;
+	include_once(_ROOT_CWD . $f);
+}
+
 
 // surcharge possible de autoriser(), sinon autoriser_dist()
 if (!function_exists('autoriser')) {
@@ -59,7 +65,7 @@ function autoriser_dist($faire, $type='', $id=0, $qui = NULL, $opt = NULL) {
 	// Qui ? visiteur_session ?
 	// si null ou '' (appel depuis #AUTORISER) on prend l'auteur loge
 	if ($qui === NULL OR $qui==='')
-	  $qui = $GLOBALS['visiteur_session'] ? $GLOBALS['visiteur_session'] : array('statut' => '', 'id_auteur' =>0);
+	  $qui = $GLOBALS['visiteur_session'] ? $GLOBALS['visiteur_session'] : array('statut' => '', 'id_auteur' =>0, 'webmestre' => 'non');
 	elseif (is_numeric($qui)) {
 		$qui = sql_fetsel("*", "spip_auteurs", "id_auteur=".$qui);
 	}
@@ -81,23 +87,23 @@ function autoriser_dist($faire, $type='', $id=0, $qui = NULL, $opt = NULL) {
 		return true;
 	
 	// Chercher une fonction d'autorisation
-	// Dans l'ordre on va chercher autoriser_type_faire, autoriser_type,
-	// autoriser_faire, autoriser_defaut ; puis les memes avec _dist
+	// Dans l'ordre on va chercher autoriser_type_faire[_dist], autoriser_type[_dist],
+	// autoriser_faire[_dist], autoriser_defaut[_dist]
 	$fonctions = $type
 		? array (
 			'autoriser_'.$type.'_'.$faire,
-			'autoriser_'.$type,
-			'autoriser_'.$faire,
-			'autoriser_defaut',
 			'autoriser_'.$type.'_'.$faire.'_dist',
+			'autoriser_'.$type,
 			'autoriser_'.$type.'_dist',
+			'autoriser_'.$faire,
 			'autoriser_'.$faire.'_dist',
+			'autoriser_defaut',
 			'autoriser_defaut_dist'
 		)
 		: array (
 			'autoriser_'.$faire,
-			'autoriser_defaut',
 			'autoriser_'.$faire.'_dist',
+			'autoriser_defaut',
 			'autoriser_defaut_dist'
 		);
 	
@@ -150,6 +156,27 @@ function autoriser_previsualiser_dist($faire, $type, $id, $qui, $opt) {
 		!==false;
 }
 
+function autoriser_dater_dist($faire, $type, $id, $qui, $opt) {
+	if (!isset($opt['statut'])){
+		$table = table_objet($type);
+		$trouver_table = charger_fonction('trouver_table','base');
+		$desc = $trouver_table($table);
+		if (!$desc)
+			return false;
+		if (isset($desc['field']['statut'])){
+			$statut = sql_getfetsel("statut", $desc['table'], id_table_objet($type)."=".intval($id));
+		}
+		else
+			$statut = 'publie'; // pas de statut => publie
+	}
+	else
+		$statut = $opt['statut'];
+
+	if ($statut == 'publie'
+	 OR ($statut == 'prop' AND $type=='article' AND $GLOBALS['meta']["post_dates"] == "non"))
+		return autoriser('modifier', $type, $id);
+	return false;
+}
 // Autoriser a publier dans la rubrique $id
 // http://doc.spip.org/@autoriser_rubrique_publierdans_dist
 function autoriser_rubrique_publierdans_dist($faire, $type, $id, $qui, $opt) {
@@ -276,6 +303,20 @@ function autoriser_document_modifier_dist($faire, $type, $id, $qui, $opt){
 }
 
 
+// On ne peut supprimer un document que s'il n'est lie a aucun objet
+// c'est autorise pour tout auteur ayant acces a ecrire
+// http://doc.spip.org/@autoriser_document_modifier_dist
+function autoriser_document_supprimer_dist($faire, $type, $id, $qui, $opt){
+	if (!intval($id)
+		OR !$qui['id_auteur']
+		OR !autoriser('ecrire','','',$qui))
+		return false;
+	if (sql_countsel('spip_documents_liens', 'id_document='.intval($id)))
+		return false;
+
+	return true;
+}
+
 // Autoriser a modifier la breve $id
 // = admins & redac si la breve n'est pas publiee
 // = admins de rubrique parente si publiee
@@ -353,6 +394,14 @@ function autoriser_voir_dist($faire, $type, $id, $qui, $opt) {
 		return autoriser_document_voir_dist($faire, $type, $id, $qui, $opt);
 	if ($qui['statut'] == '0minirezo') return true;
 	if ($type == 'auteur') return false;
+	if ($type == 'groupemots') {
+		$acces = sql_fetsel("comite,forum", "spip_groupes_mots", "id_groupe=".intval($id));
+		if ($qui['statut']=='1comite' AND ($acces['comite'] == 'oui' OR $acces['forum'] == 'oui'))
+			return true;
+		if ($qui['statut']=='6forum' AND $acces['forum'] == 'oui')
+			return true;
+		return false;
+	}
 	if ($type != 'article') return true;
 	if (!$id) return false;
 
@@ -413,8 +462,9 @@ function autoriser_modererpetition_dist($faire, $type, $id, $qui, $opt) {
 // http://doc.spip.org/@autoriser_webmestre_dist
 function autoriser_webmestre_dist($faire, $type, $id, $qui, $opt) {
 	return
-		defined('_ID_WEBMESTRES')
-		AND in_array($qui['id_auteur'], explode(':', _ID_WEBMESTRES))
+		(defined('_ID_WEBMESTRES')?
+			in_array($qui['id_auteur'], explode(':', _ID_WEBMESTRES))
+			:$qui['webmestre']=='oui')
 		AND $qui['statut'] == '0minirezo'
 		AND !$qui['restreint']
 		;
@@ -472,9 +522,11 @@ function autoriser_auteur_modifier_dist($faire, $type, $id, $qui, $opt) {
 	// Un redacteur peut modifier ses propres donnees mais ni son login/email
 	// ni son statut (qui sont le cas echeant passes comme option)
 	if ($qui['statut'] == '1comite') {
-		if ($opt['statut'] OR $opt['restreintes'] OR $opt['email'])
+		if ($opt['webmestre'])
 			return false;
-		else if ($id == $qui['id_auteur'])
+		elseif ($opt['statut'] OR $opt['restreintes'] OR $opt['email'])
+			return false;
+		elseif ($id == $qui['id_auteur'])
 			return true;
 		else
 			return false;
@@ -483,10 +535,11 @@ function autoriser_auteur_modifier_dist($faire, $type, $id, $qui, $opt) {
 	// Un admin restreint peut modifier/creer un auteur non-admin mais il
 	// n'a le droit ni de le promouvoir admin, ni de changer les rubriques
 	if ($qui['restreint']) {
-		if ($opt['statut'] == '0minirezo'
-		OR $opt['restreintes']) {
+		if ($opt['webmestre'])
 			return false;
-		} else {
+		elseif ($opt['statut'] == '0minirezo' OR $opt['restreintes'])
+			return false;
+		else {
 			if ($id == $qui['id_auteur']) {
 				if ($opt['statut'])
 					return false;
@@ -510,6 +563,13 @@ function autoriser_auteur_modifier_dist($faire, $type, $id, $qui, $opt) {
 	// sauf se degrader
 	if ($id == $qui['id_auteur'] && $opt['statut'])
 		return false;
+	// et toucher au statut webmestre si il ne l'est pas lui meme
+	// ou si les webmestres sont fixes par constante (securite)
+	elseif ($opt['webmestre'] AND (defined('_ID_WEBMESTRES') OR !autoriser('webmestre')))
+		return false;
+	// et toucher au statut d'un webmestre si il ne l'est pas lui meme
+	elseif ($opt['statut'] AND autoriser('webmestre','',0,$id) AND !autoriser('webmestre'))
+		return false;
 	else
 		return true;
 }
