@@ -15,6 +15,16 @@ if (!defined("_ECRIRE_INC_VERSION")) return;
 include_spip('inc/charsets');
 include_spip('inc/filtres_mini');
 
+/**
+ * Charger un filtre depuis le php :
+ * - on inclue tous les fichiers fonctions des plugins et du skel
+ * - on appelle chercher_filtre
+ */
+function charger_filtre($fonc, $default=NULL) {
+	include_spip('public/parametrer'); // inclure les fichiers fonctions
+	return chercher_filtre($fonc, $default);
+}
+
 // http://adoc.spip.org/@chercher_filtre
 function chercher_filtre($fonc, $default=NULL) {
 	// Cas MIME = type/subtype
@@ -122,6 +132,7 @@ $GLOBALS['spip_matrice']['filtre_audio_x_pn_realaudio'] = 'inc/filtres_mime.php'
 // charge les fonctions graphiques et applique celle demandee
 // http://doc.spip.org/@filtrer
 function filtrer($filtre) {
+	include_spip('public/parametrer'); // charger les fichiers fonctions
 	if (is_string($f = $GLOBALS['spip_matrice'][$filtre]))
 		find_in_path($f,'', true);
 	$tous = func_get_args();
@@ -459,20 +470,23 @@ function PtoBR($texte){
 // http://doc.spip.org/@lignes_longues
 function lignes_longues($texte, $l = 70) {
 	if ($l<1) return $texte;
+	if (!preg_match("/[\w,\/.]{".$l."}/UmsS", $texte))
+		return $texte;
 	// Passer en utf-8 pour ne pas avoir de coupes trop courtes avec les &#xxxx;
 	// qui prennent 7 caracteres
 	#include_spip('inc/charsets');
+	$texte = str_replace("&nbsp;","<&nbsp>",$texte);
 	$texte = html2unicode($texte, true);
+	$texte = str_replace("<&nbsp>","&nbsp;",$texte);
 	$texte = unicode_to_utf_8(charset2unicode(
 		$texte, $GLOBALS['meta']['charset'], true));
 
 	// echapper les tags (on ne veut pas casser les a href=...)
 	$tags = array();
-	if (preg_match_all('/<.+>|&(amp;)?#[0-9]+;|&(amp;)?[a-zA-Z1-4]{2,6};/UumsS', $texte, $t, PREG_SET_ORDER)) {
+	if (preg_match_all('/<.+>|&(?:amp;)?#x?[0-9]+;|&(?:amp;)?[a-zA-Z1-4]{2,6};/UumsS', $texte, $t, PREG_SET_ORDER)) {
 		foreach ($t as $n => $tag) {
-			$space = substr($tag[0],0,1)=='&'?'':' ';
 			$tags[$n] = $tag[0];
-			$texte = str_replace($tag[0], "$space<---$n--->$space", $texte);
+			$texte = str_replace($tag[0], "<---$n--->", $texte);
 		}
 	}
 	// casser les mots longs qui restent
@@ -1729,7 +1743,8 @@ function form_hidden($action) {
 
 	$fond = ''; // inutilise mais necessaire
 	$contexte = array();
-	if ($renommer = generer_url_entite()
+	if (
+			($renommer = generer_url_entite() OR $renommer = charger_fonction('page','urls'))
 	AND $p = $renommer($action, $fond, $contexte)
 	AND $p[3]) {
 		$contexte = $p[0];
@@ -1871,11 +1886,18 @@ function filtre_pagination_dist($total, $nom, $position, $pas, $liste = true, $m
 function urls_absolues_css($contenu, $source) {
 	$path = suivre_lien(url_absolue($source),'./');
 
-	return preg_replace_callback(
+	$contenu = preg_replace_callback(
 		",url\s*\(\s*['\"]?([^'\"/][^:]*)['\"]?\s*\),Uims",
 		create_function('$x',
 			'return "url(\"".suivre_lien("'.$path.'",$x[1])."\")";'
 		), $contenu);
+	// pour les progid:DXImageTransform.Microsoft.AlphaImageLoader(src=...,..)
+	$contenu = preg_replace_callback(
+		";\(\s*src=['\"]?([^'\"/][^:]*)['\"]?\s*(,|\));Uims",
+		create_function('$x',
+			'return "(src=\"".suivre_lien("'.$path.'",$x[1])."\"".$x[2];'
+		), $contenu);
+	return $contenu;
 }
 
 // recuperere le chemin d'une css existante et :
@@ -1902,19 +1924,34 @@ function direction_css ($css, $voulue='') {
 	if ($voulue == $dir)
 		return $css;
 
-	// 1.
-	$f = preg_replace(',(_rtl)?\.css$,i', '_'.$ndir.'.css', $css);
-	if (@file_exists($f))
-		return $f;
+	if (
+		// url absolue
+		preg_match(",^http:,i",$css)
+		// ou qui contient un ?
+		OR (($p=strpos($css,'?'))!==FALSE)) {
+		$distant = true;
+		$cssf = parse_url($css);
+		$cssf = $cssf['path'].($cssf['query']?"?".$cssf['query']:"");
+		$cssf = preg_replace(',[\W],', "_", $cssf);
+	}
+	else {
+		$distant = false;
+		$cssf = $css;
+		// 1. regarder d'abord si un fichier avec la bonne direction n'est pas aussi
+		//propose (rien a faire dans ce cas)
+		$f = preg_replace(',(_rtl)?\.css$,i', '_'.$ndir.'.css', $css);
+		if (@file_exists($f))
+			return $f;
+	}
 
 	// 2.
 	$dir_var = sous_repertoire (_DIR_VAR, 'cache-css');
 	$f = $dir_var
-		. preg_replace(',.*/(.*?)(_rtl)?\.css,', '\1', $css)
-		. '.' . substr(md5($css), 0,4) . '_' . $ndir . '.css';
+		. preg_replace(',.*/(.*?)(_rtl)?\.css,', '\1', $cssf)
+		. '.' . substr(md5($cssf), 0,4) . '_' . $ndir . '.css';
 
 	// la css peut etre distante (url absolue !)
-	if (preg_match(",^http:,i",$css)){
+	if ($distant){
 		include_spip('inc/distant');
 		$contenu = recuperer_page($css);
 		if (!$contenu) return $css;
@@ -2109,12 +2146,12 @@ function f_jQuery ($texte) {
 		erreur_squelette(array('double_occurrence', array('balise' => "INSERT_HEAD")));
 	} else {
 		$x = '';
-		foreach (pipeline('jquery_plugins',
+		foreach (array_unique(pipeline('jquery_plugins',
 		array(
 			'javascript/jquery.js',
 			'javascript/jquery.form.js',
 			'javascript/ajaxCallback.js'
-		)) as $script)
+		))) as $script)
 			if ($script = find_in_path($script))
 				$x .= "\n<script src=\"$script\" type=\"text/javascript\"></script>\n";
 		$texte = $x.$texte;
@@ -2227,17 +2264,25 @@ function filtre_info_plugin_dist($plugin, $type_info) {
 	$plugin = strtoupper($plugin);
 	$plugins_actifs = liste_plugin_actifs();
 
-	if(!$plugin)
+	if (!$plugin)
 		return serialize(array_keys($plugins_actifs));
-	if(!empty($plugins_actifs[$plugin]))
-		if($type_info == 'est_actif')
-			return $plugins_actifs[$plugin] ? 1 : 0;
+	elseif (empty($plugins_actifs[$plugin]))
+		return '';
+	elseif ($type_info == 'est_actif')
+		return $plugins_actifs[$plugin] ? 1 : 0;
+	elseif (isset($plugins_actifs[$plugin][$type_info]))
+		return $plugins_actifs[$plugin][$type_info];
+	else {
+		$get_infos = charger_fonction('get_infos','plugins');
+		$infos = $get_infos($plugins_actifs[$plugin]['dir']);
+		if ($type_info == 'tout')
+			return $infos;
 		else
-			return $plugins_actifs[$plugin][$type_info];
+			return strval($infos[$type_info]);
+	}
 }
 
 
-
 // http://doc.spip.org/@chercher_rubrique
 function chercher_rubrique($msg,$id, $id_parent, $type, $id_secteur, $restreint,$actionable = false, $retour_sans_cadre=false){
 	global $spip_lang_right;
@@ -2556,13 +2601,15 @@ function nouvelle_revision($x) {
  * @param string $url
  * @param string $class
  * @param string $confirm
+ * @param string $title
  * @return string
  */
-function bouton_action($libelle, $url, $class="", $confirm=""){
+function bouton_action($libelle, $url, $class="", $confirm="", $title=""){
 	$onclick = $confirm?" onclick='return confirm(\"" . attribut_html($confirm) . "\");'":"";
+	$title = $title ? " title='$title'" : "";
 
 	return "<form class='bouton_action_post $class' method='post' action='$url'><div>".form_hidden($url)
-		."<button type='submit' class='submit'$onclick>$libelle</button></div></form>";
+		."<button type='submit' class='submit'$title$onclick>$libelle</button></div></form>";
 }
 
 
