@@ -31,14 +31,14 @@ function install_fichier_connexion($nom, $texte)
 // http://doc.spip.org/@install_connexion
 function install_connexion($adr, $port, $login, $pass, $base, $type, $pref, $ldap='')
 {
-	$adr = addslashes($adr);
-	$port = addslashes($port);
-	$login = addslashes($login);
-	$pass = addslashes($pass);
-	$base = addslashes($base);
-	$type = addslashes($type);
-	$pref = addslashes($pref);
-	$ldap = addslashes($ldap);
+	$adr = addcslashes($adr,"'\\");
+	$port = addcslashes($port,"'\\");
+	$login = addcslashes($login,"'\\");
+	$pass = addcslashes($pass,"'\\");
+	$base = addcslashes($base,"'\\");
+	$type = addcslashes($type,"'\\");
+	$pref = addcslashes($pref,"'\\");
+	$ldap = addcslashes($ldap,"'\\");
 	return "\$GLOBALS['spip_connect_version'] = 0.7;\n"
 	. "spip_connect_db("
 	. "'$adr','$port','$login','$pass','$base'"
@@ -276,9 +276,7 @@ function install_select_serveur()
 // http://doc.spip.org/@install_connexion_form
 function install_connexion_form($db, $login, $pass, $predef, $hidden, $etape)
 {
-	if (is_string($predef[0])) {
-		$server_db = $predef[0];
-	}
+	$server_db = (is_string($predef[0])) ? $predef[0] : '';
 
 	return generer_form_ecrire('install', (
 	  "\n<input type='hidden' name='etape' value='$etape' />"
@@ -314,7 +312,7 @@ function install_connexion_form($db, $login, $pass, $predef, $hidden, $etape)
 	. ($server_db
 		? '<input type="hidden" name="server_db" value="'.$server_db.'" />'
 			. (($predef[0])
-			   ?('<b>'._T('install_serveur_hebergeur').'</b>')
+			   ?('<h3>'._T('install_serveur_hebergeur').'</h3>')
 				:'')
 		: ('<fieldset><legend>'
 		   ._T('install_select_type_db')
@@ -323,7 +321,7 @@ function install_connexion_form($db, $login, $pass, $predef, $hidden, $etape)
 			. _T('install_types_db_connus')
 			// Passer l'avertissement SQLIte en  commentaire, on pourra facilement le supprimer par la suite sans changer les traductions.
 			. "<br /><small>(". _T('install_types_db_connus_avertissement') .')</small>'
-			.'</label>'		
+			.'</label>'
 		. "\n<div style='text-align: center;'><select name='server_db' id='sql_serveur_db' >\n"
 		.   join("\n", install_select_serveur())
 		. "\n</select></div></fieldset>")
@@ -402,7 +400,7 @@ function predef_ou_cache($adresse_db, $login_db, $pass_db, $server_db)
 // presentation des bases existantes
 
 // http://doc.spip.org/@install_etape_liste_bases
-function install_etape_liste_bases($server_db, $disabled=array())
+function install_etape_liste_bases($server_db, $login_db, $disabled=array())
 {
 	$result = sql_listdbs($server_db);
 	if (!$result) return '';
