@@ -28,11 +28,11 @@ function var2js($var) {
 		case is_null($var) :
 			return 'null';
 		case is_string($var) :
-			return '"' . str_replace('&', '\x26', addcslashes($var, "\"\\\n\r")) . '"';
+			return '"' .addcslashes($var, "\"\\\n\r/") . '"';
 		case is_bool($var) :
 			return $var ? 'true' : 'false';
 		case is_scalar($var) :
-			return $var;
+			return (string)$var;
 		case is_object( $var) :
 			$var = get_object_vars($var);
 			$asso = true;
@@ -49,22 +49,26 @@ function var2js($var) {
 					$ret .= $sep . '"' . $key . '":' . var2js($elt);
 					$sep = ',';
 				}
-				return $ret ."}\n";
+				return $ret ."}";
 			} else {
 				$ret = '[';
 				foreach ($var as $elt) {
 					$ret .= $sep . var2js($elt);
 					$sep = ',';
 				}
-				return $ret ."]\n";
+				return $ret ."]";
 			}
 	}
 	return false;
 }
 
+if(!function_exists('json_encode')) {
+	function json_encode($v) { return var2js($v); }
+}
+
 // http://doc.spip.org/@json_export
 function json_export($var) {
-	$var = var2js($var);
+	$var = json_encode($var);
 
 	// flag indiquant qu'on est en iframe et qu'il faut proteger nos
 	// donnees dans un <textarea> ; attention $_FILES a ete vide par array_pop
