@@ -289,8 +289,10 @@ function liste_plugin_actifs(){
   	if (is_array($t=unserialize($meta_plugin)))
   		return $t;
   	else{ // compatibilite pre 1.9.2, mettre a jour la meta
+			spip_log("MAJ meta plugin vieille version : $meta_plugin","plugin");
   		$t = explode(",",$meta_plugin);
   		list($liste,,) = liste_plugin_valides($t);
+			include_spip('inc/meta');
 			ecrire_meta('plugin',serialize($liste));
 			return $liste;
   	}
@@ -346,6 +348,7 @@ function ecrire_plugin_actifs($plugin,$pipe_recherche=false,$operation='raz') {
 	list($plugin_valides,$ordre,$infos) = liste_plugin_valides($plugin,true);
 
 	ecrire_meta('plugin',serialize($plugin_valides));
+	effacer_meta('message_crash_plugins'); // baisser ce flag !
 	$plugin_header_info = array();
 	foreach($plugin_valides as $p=>$resume){
 		$plugin_header_info[]= $p.($resume['version']?"(".$resume['version'].")":"");
@@ -573,24 +576,32 @@ function actualise_plugins_actifs($pipe_recherche = false){
 	$actifs_avant = $GLOBALS['meta']['plugin'];
 	ecrire_plugin_actifs($plugin_new,$pipe_recherche);
 	// retourner -1 si la liste des plugins actifs a change
-	return strcmp($GLOBALS['meta']['plugin'],$actifs_avant)==0 ? 1 : -1;
+	return (strcmp($GLOBALS['meta']['plugin'],$actifs_avant)==0) ? 1 : -1;
 }
 
 // http://doc.spip.org/@spip_plugin_install
-function spip_plugin_install($action,$prefix,$version_cible){
-	$nom_meta_base_version = $prefix."_base_version";
+function spip_plugin_install($action, $infos){
+	$prefix = $infos['prefix'];
+	$version_cible = $infos['version_base'];
+	if (isset($infos['meta']) AND (($table = $infos['meta']) !== 'meta'))
+		$nom_meta = "base_version";
+	else {  
+		$nom_meta = $prefix."_base_version";
+		$table = 'meta';
+	}
 	switch ($action){
 		case 'test':
-			return (isset($GLOBALS['meta'][$nom_meta_base_version]) 
-			  AND spip_version_compare($GLOBALS['meta'][$nom_meta_base_version],$version_cible,'>='));
+			return (isset($GLOBALS[$table])
+			AND isset($GLOBALS[$table][$nom_meta]) 
+			AND spip_version_compare($GLOBALS[$table][$nom_meta],$version_cible,'>='));
 			break;
 		case 'install':
 			if (function_exists($upgrade = $prefix."_upgrade"))
-				$upgrade($nom_meta_base_version,$version_cible);
+				$upgrade($nom_meta, $version_cible, $table);
 			break;
 		case 'uninstall':
 			if (function_exists($vider_tables = $prefix."_vider_tables"))
-				$vider_tables($nom_meta_base_version);
+				$vider_tables($nom_meta, $table);
 			break;
 	}
 }
@@ -598,12 +609,7 @@ function spip_plugin_install($action,$prefix,$version_cible){
 // http://doc.spip.org/@desinstalle_un_plugin
 function desinstalle_un_plugin($plug,$infos){
 	// faire les include qui vont bien
-	foreach($infos['install'] as $file){
-		$file = trim($file);
-		if (file_exists($f = _ROOT_PLUGINS."$plug/$file")){
-			include_once($f);
-		}
-	}
+	charge_instal_plugin($plug, $infos);
 	$version_cible = isset($infos['version_base'])?$infos['version_base']:'';
 	$prefix_install = $infos['prefix']."_install";
 	if (function_exists($prefix_install)){
@@ -612,16 +618,15 @@ function desinstalle_un_plugin($plug,$infos){
 		return $ok;
 	}
 	if (isset($infos['version_base'])){
-		spip_plugin_install('uninstall',$infos['prefix'],$infos['version_base']);
-		$ok = spip_plugin_install('test',$infos['prefix'],$infos['version_base']);
+		spip_plugin_install('uninstall',$infos);
+		$ok = spip_plugin_install('test',$infos);
 		return $ok;
 	}
 
 	return false;
 }
 
-// http://doc.spip.org/@installe_un_plugin
-function installe_un_plugin($plug,$infos,$dir_plugins = '_DIR_PLUGINS'){
+function charge_instal_plugin($plug,$infos,$dir_plugins = '_DIR_PLUGINS'){
 	// passer en chemin absolu si possible
 	$dir = str_replace('_DIR_','_ROOT_',$dir_plugins);
 	if (!defined($dir))
@@ -634,6 +639,12 @@ function installe_un_plugin($plug,$infos,$dir_plugins = '_DIR_PLUGINS'){
 			include_once($f);
 		}
 	}
+}
+
+function installe_un_plugin($plug,$infos,$dir_plugins = '_DIR_PLUGINS'){
+
+	charge_instal_plugin($plug, $infos, $dir_plugins);
+
 	$version_cible = isset($infos['version_base'])?$infos['version_base']:'';
 	$prefix_install = $infos['prefix']."_install";
 	// cas de la fonction install fournie par le plugin
@@ -656,12 +667,12 @@ function installe_un_plugin($plug,$infos,$dir_plugins = '_DIR_PLUGINS'){
 	// pas de fonction instal fournie, mais une version_base dans le plugin
 	// on utilise la fonction par defaut
 	if (isset($infos['version_base'])){
-		$ok = spip_plugin_install('test',$infos['prefix'],$infos['version_base']);
+		$ok = spip_plugin_install('test',$infos);
 		if (!$ok) {
 			echo "<div class='install-plugins'>";
 			echo _T('plugin_titre_installation',array('plugin'=>typo($infos['nom'])))."<br />";
-			spip_plugin_install('install',$infos['prefix'],$infos['version_base']);
-			$ok = spip_plugin_install('test',$infos['prefix'],$infos['version_base']);
+			spip_plugin_install('install',$infos);
+			$ok = spip_plugin_install('test',$infos);
 			// vider le cache des definitions des tables
 			$trouver_table = charger_fonction('trouver_table','base');
 			$trouver_table(false);
@@ -713,6 +724,7 @@ function plugin_est_installe($plug_path){
 
 // http://doc.spip.org/@verifie_include_plugins
 function verifie_include_plugins() {
+	include_spip('inc/meta');
 	ecrire_meta('message_crash_plugins', 1);
 
 /*	if (_request('exec')!="admin_plugin"
