@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -59,7 +59,7 @@ function definir_raccourcis_alineas()
 	static $alineas = array();
 	$x = _DIR_RESTREINT ? lang_dir() : lang_dir($GLOBALS['spip_lang']);
 	if (!isset($alineas[$x])) {
-        
+
 		$alineas[$x] = array(
 		array(
 		/* 0 */ 	"/\n(----+|____+)/S",
@@ -106,10 +106,10 @@ define('_BALISES_BLOCS',
 	'div|pre|ul|ol|li|blockquote|h[1-6r]|'
 	.'t(able|[rdh]|body|foot|extarea)|'
 	.'form|object|center|marquee|address|'
-	.'d[ltd]|script|noscript|map|button|fieldset');
+	.'d[ltd]|script|noscript|map|button|fieldset|style');
 
 //
-// Echapper les les elements perilleux en les passant en base64
+// Echapper les elements perilleux en les passant en base64
 //
 
 // Creer un bloc base64 correspondant a $rempl ; au besoin en marquant
@@ -127,10 +127,10 @@ function code_echappement($rempl, $source='', $no_transform=false) {
 	// Decouper en morceaux, base64 a des probleme selon la taille de la pile
 	$taille = 30000;
 	for($i = 0; $i < strlen($rempl); $i += $taille) {
-		// Convertir en base64
+		// Convertir en base64 et cacher dans un attribut
+		// utiliser les " pour eviter le re-encodage de ' et &#8217
 		$base64 = base64_encode(substr($rempl, $i, $taille));
-		$return .= inserer_attribut("<$mode class=\"base64$source\">",
-				'title', $base64) ."</$mode>";
+		$return .= "<$mode class=\"base64$source\" title=\"$base64\"></$mode>";
 	}
 
 	return $return
@@ -150,7 +150,8 @@ function traiter_echap_html_dist($regs) {
 // Echapper les <code>...</ code>
 // http://doc.spip.org/@traiter_echap_code_dist
 function traiter_echap_code_dist($regs) {
-	$echap = htmlspecialchars($regs[3]); // il ne faut pas passer dans entites_html, ne pas transformer les &#xxx; du code ! 
+	list(,,$att,$corps) = $regs;
+	$echap = htmlspecialchars($corps); // il ne faut pas passer dans entites_html, ne pas transformer les &#xxx; du code !
 
 	// ne pas mettre le <div...> s'il n'y a qu'une ligne
 	if (is_int(strpos($echap,"\n"))) {
@@ -159,15 +160,13 @@ function traiter_echap_code_dist($regs) {
 		$echap = preg_replace("/^[\n\r]+|[\n\r]+$/s", "", $echap);
 		$echap = nl2br($echap);
 		$echap = "<div style='text-align: left;' "
-		. "class='spip_code' dir='ltr'><code>"
+		. "class='spip_code' dir='ltr'><code$att>"
 		.$echap."</code></div>";
 	} else {
-		$echap = "<code class='spip_code' "
-		."dir='ltr'>".$echap."</code>";
+		$echap = "<code$att class='spip_code' dir='ltr'>".$echap."</code>";
 	}
 
-	$echap = str_replace("\t",
-		"&nbsp; &nbsp; &nbsp; &nbsp; ", $echap);
+	$echap = str_replace("\t", "&nbsp; &nbsp; &nbsp; &nbsp; ", $echap);
 	$echap = str_replace("  ", " &nbsp;", $echap);
 	return $echap;
 }
@@ -253,16 +252,26 @@ $preg='') {
 //
 // Traitement final des echappements
 // Rq: $source sert a faire des echappements "a soi" qui ne sont pas nettoyes
-// par propre() : exemple dans ecrire/inc_articles_ortho.php, $source='ORTHO'
-// ou encore dans typo()
+// par propre() : exemple dans multi et dans typo()
 // http://doc.spip.org/@echappe_retour
 function echappe_retour($letexte, $source='', $filtre = "") {
 	if (strpos($letexte,"base64$source")) {
 		# spip_log(htmlspecialchars($letexte));  ## pour les curieux
-		if (preg_match_all(',<(span|div) class=[\'"]base64'.$source.'[\'"]\s.*>\s*</\1>,UmsS',
+		if (preg_match_all(',<(span|div) class=[\'"]base64'.$source.'[\'"]\s(.*)>\s*</\1>,UmsS',
 		$letexte, $regs, PREG_SET_ORDER)) {
 			foreach ($regs as $reg) {
 				$rempl = base64_decode(extraire_attribut($reg[0], 'title'));
+				// recherche d'attributs supplementaires
+				$at = array();
+				foreach(array('lang', 'dir') as $attr) {
+					if ($a = extraire_attribut($reg[0], $attr))
+						$at[$attr] = $a;
+				}
+				if ($at) {
+					$rempl = '<'.$reg[1].'>'.$rempl.'</'.$reg[1].'>';
+					foreach($at as $attr => $a)
+						$rempl = inserer_attribut($rempl, $attr, $a);
+				}
 				if ($filtre) $rempl = $filtre($rempl);
 				$letexte = str_replace($reg[0], $rempl, $letexte);
 			}
@@ -321,7 +330,7 @@ function couper($texte, $taille=50, $suite = '&nbsp;(...)') {
 	$texte = unicode2charset(html2unicode($texte, /* secure */ true));
 	$texte = nettoyer_raccourcis_typo($texte);
 
-	// corriger la longueur de coupe 
+	// corriger la longueur de coupe
 	// en fonction de la presence de caracteres utf
 	if ($GLOBALS['meta']['charset']=='utf-8'){
 		$long = charset2unicode($texte);
@@ -403,12 +412,17 @@ function protege_js_modeles($t) {
 // il ne faut pas desactiver globalement la fonction dans l'espace prive car elle protege
 // aussi les balises des squelettes qui ne passent pas forcement par propre ou typo apres
 // http://doc.spip.org/@interdire_scripts
-function interdire_scripts($t) {
-	// rien ?
-	if (!$t OR !strstr($t, '<')) return $t;
+function interdire_scripts($arg) {
+	// on memorise le resultat sur les arguments non triviaux
+	static $dejavu = array();
+
+	// Attention, si ce n'est pas une chaine, laisser intact
+	if (!$arg OR !is_string($arg) OR !strstr($arg, '<')) return $arg;
+
+	if (isset($dejavu[$GLOBALS['filtrer_javascript']][$arg])) return $dejavu[$GLOBALS['filtrer_javascript']][$arg];
 
 	// echapper les tags asp/php
-	$t = str_replace('<'.'%', '&lt;%', $t);
+	$t = str_replace('<'.'%', '&lt;%', $arg);
 
 	// echapper le php
 	$t = str_replace('<'.'?', '&lt;?', $t);
@@ -436,7 +450,7 @@ function interdire_scripts($t) {
 	if (defined('_PROTEGE_PHP_MODELES'))
 		$t = echappe_retour($t,"php"._PROTEGE_PHP_MODELES);
 
-	return $t;
+	return $dejavu[$GLOBALS['filtrer_javascript']][$arg] = $t;
 }
 
 // Securite : utiliser SafeHTML s'il est present dans ecrire/safehtml/
@@ -452,7 +466,7 @@ function safehtml($t) {
 	$t = echappe_js($t);
 
 	if (!isset($safehtml))
-		$safehtml = charger_fonction('safehtml', 'inc');
+		$safehtml = charger_fonction('safehtml', 'inc', true);
 	if ($safehtml)
 		$t = $safehtml($t);
 
@@ -508,8 +522,13 @@ function typo($letexte, $echapper=true, $connect=null) {
 
 // Correcteur typographique
 
+define('_TYPO_PROTEGER', "!':;?~%-");
+define('_TYPO_PROTECTEUR', "\x1\x2\x3\x4\x5\x6\x7\x8");
+
+define('_TYPO_BALISE', ",</?[a-z!][^<>]*[".preg_quote(_TYPO_PROTEGER)."][^<>]*>,imsS");
+
 // http://doc.spip.org/@corriger_typo
-function corriger_typo($letexte) {
+function corriger_typo($letexte, $lang='') {
 
 	// Plus vite !
 	if (!$letexte) return $letexte;
@@ -519,31 +538,32 @@ function corriger_typo($letexte) {
 	// Caracteres de controle "illegaux"
 	$letexte = corriger_caracteres($letexte);
 
-	// Charger & appliquer la fonction de typographie
-
-	if ($typographie = charger_fonction(lang_typo(), 'typographie')) {
-
-		// Proteger les caracteres typographiques a l'interieur des tags html
-		$protege = "!':;?~%-";
-		$illegal = "\x1\x2\x3\x4\x5\x6\x7\x8";
-		if (preg_match_all(',</?[a-z!][^<>]*['.preg_quote($protege).'][^<>]*>,imsS',
-		$letexte, $regs, PREG_SET_ORDER)) {
-			foreach ($regs as $reg) {
-				$insert = $reg[0];
-				// hack: on transforme les caracteres a proteger en les remplacant
-				// par des caracteres "illegaux". (cf corriger_caracteres())
-				$insert = strtr($insert, $protege, $illegal);
-				$letexte = str_replace($reg[0], $insert, $letexte);
-			}
+	// Proteger les caracteres typographiques a l'interieur des tags html
+	if (preg_match_all(_TYPO_BALISE, $letexte, $regs, PREG_SET_ORDER)) {
+		foreach ($regs as $reg) {
+			$insert = $reg[0];
+			// hack: on transforme les caracteres a proteger en les remplacant
+			// par des caracteres "illegaux". (cf corriger_caracteres())
+			$insert = strtr($insert, _TYPO_PROTEGER, _TYPO_PROTECTEUR);
+			$letexte = str_replace($reg[0], $insert, $letexte);
 		}
-
-		$letexte = $typographie($letexte);
-
-		// Retablir les caracteres proteges
-		$letexte = strtr($letexte, $illegal, $protege);
-
 	}
 
+	// trouver les blocs multi et les traiter a part
+	$letexte = extraire_multi($e = $letexte, $lang, true);
+	$e = ($e === $letexte);
+
+	// Charger & appliquer les fonctions de typographie
+	$typographie = charger_fonction(lang_typo($lang), 'typographie');
+	$letexte = $typographie($letexte);
+
+	// Les citations en une autre langue, s'il y a lieu
+	if (!$e) $letexte = echappe_retour($letexte, 'multi');
+
+	// Retablir les caracteres proteges
+	$letexte = strtr($letexte, _TYPO_PROTECTEUR, _TYPO_PROTEGER);
+
+	// pipeline
 	$letexte = pipeline('post_typo', $letexte);
 
 	# un message pour abs_url - on est passe en mode texte
@@ -553,7 +573,6 @@ function corriger_typo($letexte) {
 }
 
 
-
 //
 // Tableaux
 //
@@ -601,6 +620,8 @@ function traiter_tableau($bloc) {
 						$attr= " colspan='$colspan'";
 						$colspan=1;
 					  }
+					  // inutile de garder le strong qui n'a servi que de marqueur 
+					  $cols[$c] = str_replace(array('{','}'), '', $cols[$c]);
 					  $ligne= "<th scope='col'$attr>$cols[$c]</th>$ligne";
 					}
 				}
@@ -618,7 +639,7 @@ function traiter_tableau($bloc) {
 				$ligne = traiter_listes($ligne);
 
 			// Pas de paragraphes dans les cellules
-			$ligne = preg_replace("/\n{2,}/", "<br />\n", $ligne);
+			$ligne = preg_replace("/\n{2,}/", "<br /><br />\n", $ligne);
 
 			// tout mettre dans un tableau 2d
 			preg_match_all('/\|([^|]*)/S', $ligne, $cols);
@@ -663,7 +684,7 @@ function traiter_tableau($bloc) {
 		$ligne='';
 
 		for($c=count($cols)-1; $c>=0; $c--) {
-			$attr= $numeric[$c]; 
+			$attr= $numeric[$c];
 			$cell = trim($cols[$c]);
 			if($cell=='<') {
 			  $colspan++;
@@ -812,7 +833,7 @@ function paragrapher($letexte, $forcer=true) {
 
 		// Ajouter un espace aux <p> et un "STOP P"
 		// transformer aussi les </p> existants en <p>, nettoyes ensuite
-		$letexte = preg_replace(',</?p\b.*>,UiS', '<STOP P><p \2>',
+		$letexte = preg_replace(',</?p\b\s?(.*?)>,iS', '<STOP P><p \1>',
 			'<p>'.$letexte.'<STOP P>');
 
 		// Fermer les paragraphes (y compris sur "STOP P")
