@@ -21,7 +21,7 @@ error_reporting(E_ALL ^ E_NOTICE);
 # ne concerne que le fichier mes_options.php3
 define('_EXTENSION_PHP', '.php3');
 #define('_EXTENSION_PHP', '');
-#mettre a true pour compatibilite PHP3 
+#mettre a true pour compatibilite PHP3
 define('_FEED_GLOBALS', false);
 
 
@@ -226,7 +226,7 @@ $controler_dates_rss = true;
 // class_spip : savoir si on veut class="spip" sur p i strong & li
 // class_spip_plus : class="spip" sur les ul ol h3 hr quote table...
 // la difference c'est que des css specifiques existent pour les seconds
-// 
+//
 $class_spip =  '';  /*' class="spip"'*/
 $class_spip_plus =  ' class="spip"';
 $toujours_paragrapher =  true;
@@ -320,6 +320,7 @@ $spip_pipeline = array(
 	'pre_edition' => '|premiere_revision',
 	'post_edition' => '|nouvelle_revision',
 	'pre_insertion' => '',
+	'post_insertion' => '',
 	'pre_syndication' => '',
 	'post_syndication' => '',
 	'pre_indexation' => '',
@@ -338,6 +339,7 @@ $spip_pipeline = array(
 	'recuperer_fond' => '',
 	'styliser' => '||styliser_par_rubrique|styliser_par_langue',
 	'trig_calculer_prochain_postdate' => '',
+	'trig_calculer_langues_rubriques' => '',
 	'trig_propager_les_secteurs' => '',
 	'trig_supprimer_objets_lies' => '',
 );
@@ -360,7 +362,7 @@ $table_date = array();
 $table_titre = array();
 $tables_jointures = array();
 
-// Liste des statuts. 
+// Liste des statuts.
 $liste_des_statuts = array(
 			"info_administrateurs" => '0minirezo',
 			"info_redacteurs" =>'1comite',
@@ -373,7 +375,7 @@ $liste_des_etats = array(
 			'texte_statut_propose_evaluation' => 'prop',
 			'texte_statut_publie' => 'publie',
 			'texte_statut_poubelle' => 'poubelle',
-			'texte_statut_refuse' => 'refuse' 
+			'texte_statut_refuse' => 'refuse'
 			);
 
 $liste_des_forums = array(
@@ -396,15 +398,15 @@ $liste_des_authentifications = array(
 // Droits d'acces maximum par defaut
 @umask(0);
 
-// numero de branche, utilise par les plugins 
+// numero de branche, utilise par les plugins
 // pour specifier les versions de SPIP necessaire
-// il faut s'en tenir a un nombre de decimales fixe ex : 2.0.0, 2.0.0-dev, 2.0.0-beta, 2.0.0-beta2 
-$spip_version_branche = "2.1.0";
+// il faut s'en tenir a un nombre de decimales fixe ex : 2.0.0, 2.0.0-dev, 2.0.0-beta, 2.0.0-beta2
+$spip_version_branche = "2.1.1";
 // version des signatures de fonctions PHP
 // (= numero SVN de leur derniere modif cassant la compatibilite et/ou necessitant un recalcul des squelettes)
 $spip_version_code = 15375;
-// version de la base SQL (= numero SVN de sa derniere modif, a verifier dans le fichier ecrire/maj/sv10000.php) 
-$spip_version_base = 14559;
+// version de la base SQL (= numero SVN de sa derniere modif, a verifier dans le fichier ecrire/maj/sv10000.php)
+$spip_version_base = 15828;
 
 // version de l'interface a la base
 $spip_sql_version = 1;
@@ -431,7 +433,8 @@ require_once _ROOT_RESTREINT . 'base/connect_sql.php';
 if (_FILE_OPTIONS) include_once _FILE_OPTIONS;
 
 // Masquer les warning
-define('SPIP_ERREUR_REPORT',E_ALL ^ E_NOTICE);
+@define('E_DEPRECATED',8192); // compatibilite PHP 5.3
+define('SPIP_ERREUR_REPORT',E_ALL ^ E_NOTICE ^ E_DEPRECATED);
 error_reporting(SPIP_ERREUR_REPORT);
 
 // Initialisations critiques non surchargeables par les plugins
