@@ -483,7 +483,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'info_pas_de_forum' => 'nema foruma',
 'info_passe_trop_court' => 'Prekratka lozinka.',
 'info_passes_identiques' => 'Lozinke nisu identicne.',
-'info_pense_bete_ancien' => 'Vase stare biljeske',
+'info_pense_bete_ancien' => 'Vase stare biljeske', # MODIF
 'info_plus_cinq_car' => 'vise od pet karaktera',
 'info_plus_cinq_car_2' => '(Vise od pet karaktera)',
 'info_plus_trois_car' => '(Vise od tri karaktera)',
