@@ -26,7 +26,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'avis_conseil_selection_mot_cle' => '<b>Wichtige Kategorie:</b> Bitte w&auml;hlen Sie ein Schl&uuml;sselwort dieser Gruppe.',
 'avis_deplacement_rubrique' => 'Achtung! diese Rubrik enth&auml;lt @contient_breves@ Meldungen@scb@: wenn Sie Rubrik verschieben wollen, markieren Sie bitte zur Best&auml;tigung dieses K&auml;stchen.',
 'avis_destinataire_obligatoire' => 'Sie m&uuml;ssen einen Empf&auml;nger angeben, bevor Sie die Nachricht abschicken.',
-'avis_doublon_mot_cle' => 'Dieses Schlagwort gibt es bereits. Wollen sie es wirklich anlegen?', # MODIF
+'avis_doublon_mot_cle' => 'Ein Schlagwort mit dieser Bezeichung gibt es bereits. Wollen sie es wirklich erneut anlegen?',
 'avis_erreur_connexion_mysql' => 'Verbindungsfehler (SQL)',
 'avis_erreur_version_archive' => '<b>Achtung! Die Datei @archive@ entspricht nicht der von Ihnen installierten Version von SPIP.</b> Sie riskieren die Funktionalit&auml;t Ihrer Website zu beeintr&auml;chtigen oder sogar die Datenbank zu zerst&ouml;ren. Bitte brechen Sie den Vorgang jetzt ab.<p> Mehr dazu finden Sie in der <a href="@spipnet@"> franz&ouml;sischen SPIP-Dokumentation</a>.',
 'avis_espace_interdit' => '<b>Gesperrter Bereich</b><div>SPIP ist bereits installiert.</div>',
@@ -485,7 +485,7 @@ Ihr Status wird durch die Farbe ihres Symbols angezeigt (Redakteur = gelb; Admin
 'info_pas_de_forum' => 'kein Forum',
 'info_passe_trop_court' => 'Passwort zu kurz.',
 'info_passes_identiques' => 'Die zwei Passworte stimmen nicht &uuml;berein.',
-'info_pense_bete_ancien' => 'Ihre alten Merkzettel',
+'info_pense_bete_ancien' => 'Ihre alten Merkzettel', # MODIF
 'info_plus_cinq_car' => 'mehr als 5 Zeichen',
 'info_plus_cinq_car_2' => '(mehr als 5 Zeichen)',
 'info_plus_trois_car' => '(mehr als 3 Zeichen)',
@@ -721,7 +721,7 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'item_non_bloquer_liens_syndiques' => 'Links zu syndizierten Websites nicht sperren',
 'item_non_compresseur' => 'Kompression abschalten',
 'item_non_config_forums_prive_global' => 'Forum der Redakteure abschalten',
-'item_non_config_forums_prive_objets' => 'Diese Foren desaktivieren',
+'item_non_config_forums_prive_objets' => 'Diese Foren abschalten',
 'item_non_creer_fichiers_authent' => 'Diese Dateien nicht anlegen',
 'item_non_gerer_annuaire_site_web' => 'Website-Verzeichnis abschalten',
 'item_non_gerer_statistiques' => 'Keine Statistiken anlegen',
