@@ -521,7 +521,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'info_pas_de_forum' => 'tidak ada forum',
 'info_passe_trop_court' => 'Kata sandi terlalu pendek.',
 'info_passes_identiques' => 'Dua kata sandi tidak identik.',
-'info_pense_bete_ancien' => 'Memo-memo lama anda',
+'info_pense_bete_ancien' => 'Memo-memo lama anda', # MODIF
 'info_plus_cinq_car' => 'lebih dari 5 karakter',
 'info_plus_cinq_car_2' => '(Lebih dari 5 karakter)',
 'info_plus_trois_car' => '(Lebih dari 3 karakter)',
