@@ -9,7 +9,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 // A
 'accueil_site' => 'Home page',
-'article' => 'Article', # NEW
+'article' => 'Articolo',
 'articles' => 'Articoli',
 'articles_auteur' => 'Articoli di questo autore',
 'articles_populaires' => 'Articoli pi&ugrave; letti',
@@ -19,7 +19,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'aucun_site' => 'Non ci sono siti a questo indirizzo',
 'aucune_breve' => 'Non ci sono brevi a questo indirizzo',
 'aucune_rubrique' => 'Non ci sono rubriche a questo indirizzo',
-'auteur' => 'Auteur', # NEW
+'auteur' => 'Autore',
 'autres' => 'Altri',
 'autres_breves' => 'Altre brevi',
 'autres_groupes_mots_clefs' => 'Altri gruppi di parole chiave',
@@ -27,7 +27,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 // B
 'bonjour' => 'Salve',
-'breve' => 'Br&egrave;ve', # NEW
+'breve' => 'Breve',
 'breves' => 'Brevi',
 
 // C
@@ -70,7 +70,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'message' => 'Messaggio',
 'messages_forum' => 'Messaggi del forum',
 'messages_recents' => 'Messaggi pi&ugrave; recenti del forum',
-'mots_clef' => 'Mot-cl&eacute;', # NEW
+'mots_clef' => 'Parola chiave',
 'mots_clefs' => 'Parole chiave',
 'mots_clefs_meme_groupe' => 'Parole chiave nello stesso gruppo',
 
