@@ -9,7 +9,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 // 0
 '0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-it',
-'0_langue' => 'Francese (Fr)',
+'0_langue' => 'Italiano [it]',
 '0_liste' => 'spip-it@rezo.net',
 '0_mainteneur' => 'ebottaro@hce.it',
 
@@ -222,18 +222,17 @@ di ciascuna di queste cartelle. La procedura &egrave; spiegata in dettaglio nell
 
 // F
 'fichier_introuvable' => 'File @fichier@ non trovato',
-'form_auteur_confirmation' => 'Confirma tu direcci&oacute;n de correo', # NEW
-'form_auteur_email_modifie' => 'Tu direcci&oacute;n de correo fue modificada', # NEW
-'form_auteur_envoi_mail_confirmation' => 'Se te acaba de enviar un mensaje de confirmaci&oacute;n a @email@. Tienes que visitar la p&aacute;gina web indicada en ese mensaje para validar tu direcci&oacute;n de correo.', # NEW
-'form_auteur_mail_confirmation' => 'Hola,
+'form_auteur_confirmation' => 'Per cortesia conferma il tuo indirizzo email',
+'form_auteur_email_modifie' => 'Il tuo indirizzo email &egrave; stato modificato',
+'form_auteur_envoi_mail_confirmation' => 'Una email di conferma &egrave; stata inviata a  @email@. &Egrave; necessario visitare l\'URL indicata nel messaggio per convalidare il tuo indirizzo email.',
+'form_auteur_mail_confirmation' => 'Ciao,
 
-Has solicitado cambiar tu direcci&oacute;n de correo.
-Para confirmar tu nueva direcci&oacute;n, alcanza con visitar la p&aacute;gina
-siguiente:
+Hai chiesto di modificare l\'indirizzo email.
+Per confermare la tua nuova email, devi connetterti all\'
+indirizzo qui sotto. (Altrimenti la tua richiesta sar&agrave; ignorata.):
 
     @url@
-Caso contrario, la solicitud ser&aacute; simplemente ignorada.
-', # NEW
+',
 'form_deja_inscrit' => 'Sei gi&agrave; iscritto.',
 'form_email_non_valide' => 'L\'indirizzo email non &egrave; valido.',
 'form_forum_access_refuse' => 'Non hai pi&ugrave; accesso a questo sito.',
@@ -408,16 +407,16 @@ che ti &egrave; stato fornito.  Se non sei registrato, devi',
 'info_article_supprime' => 'Articolo eliminato',
 'info_articles' => 'Articoli',
 'info_articles_a_valider' => 'Articoli da convalidare',
-'info_articles_nb' => '@nb@ art&iacute;culos', # NEW
+'info_articles_nb' => '@nb@ articoli',
 'info_articles_proposes' => 'Articoli proposti',
-'info_articles_un' => '<NEW>1 article',
+'info_articles_un' => '1 articolo',
 'info_auteurs_nombre' => 'autore(i):',
 'info_authentification_ftp' => 'Autenticazione (via FTP).',
 'info_bloquer_lien' => 'bloccare questo link',
 'info_breves_02' => 'Brevi',
 'info_breves_2' => 'brevi',
-'info_breves_nb' => '@nb@ breves', # NEW
-'info_breves_un' => '1 breve', # NEW
+'info_breves_nb' => '@nb@ notizie',
+'info_breves_un' => '1 notizia',
 'info_breves_valider' => 'Brevi da convalidare',
 'info_connexion_refusee' => 'Connessione rifiutata',
 'info_contact_developpeur' => 'Contatta un programmatore.',
@@ -438,8 +437,8 @@ che ti &egrave; stato fornito.  Se non sei registrato, devi',
 'info_document' => 'Documento',
 'info_document_indisponible' => 'Questo documento non &egrave; disponibile',
 'info_documents' => 'Documenti',
-'info_documents_nb' => '@nb@ documentos', # NEW
-'info_documents_un' => '1 documento', # NEW
+'info_documents_nb' => '@nb@ documenti',
+'info_documents_un' => '1 documento',
 'info_echange_message' => 'SPIP permette lo scambio di messaggi e la costituzione di forum di discussione
 privati tra i membri del sito. Puoi attivare o disattivare questa funzionalit&agrave;.',
 'info_ecire_message_prive' => 'Scrivi un messaggio privato',
@@ -485,8 +484,8 @@ o contatta il tuo hoster.</font>',
 'info_mail_fournisseur' => 'tuo@provider.com',
 'info_message_2' => 'MESSAGGIO',
 'info_message_supprime' => 'MESSAGGIO ELIMINATO',
-'info_messages_nb' => '@nb@ mensajes', # NEW
-'info_messages_un' => '1 mensaje', # NEW
+'info_messages_nb' => '@nb@ messaggi',
+'info_messages_un' => '1 messaggio',
 'info_mise_en_ligne' => 'Data di pubblicazione on line:',
 'info_modification_parametres_securite' => 'modifiche dei parametri di sicurezza',
 'info_mois_courant' => 'Durante il mese:',
@@ -533,8 +532,8 @@ o contatta il tuo hoster.</font>',
 'info_retablir_lien' => 'ripristinare questo link',
 'info_retirer_mot' => 'Rimuovere questa parola',
 'info_retirer_mots' => 'Rimuovere tutte le parole',
-'info_rubriques_nb' => '@nb@ secciones', # NEW
-'info_rubriques_un' => '1 secci&oacute;n', # NEW
+'info_rubriques_nb' => '@nb@ sezioni',
+'info_rubriques_un' => '1 sezione',
 'info_sans_titre_2' => 'senza titolo',
 'info_selectionner_fichier' => 'Puoi selezionare un file della cartella @upload@',
 'info_selectionner_fichier_2' => 'Seleziona un file:',
@@ -543,9 +542,9 @@ o contatta il tuo hoster.</font>',
 'info_site_attente' => 'Sito Web in attesa di convalida',
 'info_site_reference' => 'Sito repertoriato in linea',
 'info_site_refuse' => 'Sito Web rifiutato',
-'info_sites_nb' => '@nb@ sitios', # NEW
+'info_sites_nb' => '@nb@ siti',
 'info_sites_referencer' => 'Inserisci un sito in repertorio',
-'info_sites_un' => '1 sitio', # NEW
+'info_sites_un' => '1 sito',
 'info_supprimer_vignette' => 'Cancella l\'immagine',
 'info_symbole_bleu' => 'Il simbolo <b>blu</b> indica un <b>memo</b>: cio&egrave; un messaggio ad uso personale.',
 'info_symbole_jaune' => 'Il simbolo <b>giallo</b> indica un <b>annuncio a tutti i redattori</b>: modificabile da tutti gli amministratori e visibile da tutti i redattori.',
@@ -569,7 +568,7 @@ o contatta il tuo hoster.</font>',
 'info_visites' => 'visite:',
 'info_vos_rendez_vous' => 'I tuoi prossimi appuntamenti',
 'info_zoom' => 'zoom',
-'infos_vos_pense_bete' => 'I tuoi memo',
+'infos_vos_pense_bete' => 'I tuoi memo', # MODIF
 'item_breve_proposee' => 'Breve proposta',
 
 // L
@@ -618,7 +617,7 @@ devi attivare Javascript nel tuo browser e',
 'login_retour_site' => 'Ritorna al sito pubblico',
 'login_retoursitepublic' => 'ritorna&nbsp;al&nbsp;sito&nbsp;pubblico',
 'login_sans_cookiie' => 'Identificazione senza cookie',
-'login_securise' => 'Conexi&oacute;n segura', # NEW
+'login_securise' => 'Accesso protetto',
 'login_sinscrire' => 'registrati',
 'login_test_navigateur' => 'test browser/riconnessione',
 'login_verifiez_navigateur' => '(Verifica comunque se il tuo browser ha memorizzato la password...)',
