@@ -568,7 +568,7 @@ Grandmerc&eacute; per v&ograve;stra participacion
 'info_visites' => 'vesitas:',
 'info_vos_rendez_vous' => 'V&ograve;strei rend&egrave;tz-vos venents',
 'info_zoom' => 'zoom',
-'infos_vos_pense_bete' => 'V&ograve;strei mementos',
+'infos_vos_pense_bete' => 'V&ograve;strei mementos', # MODIF
 'item_breve_proposee' => 'Br&egrave;va prepausada',
 
 // L
