@@ -11,7 +11,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 '0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
 '0_langue' => 'T&uuml;rk&ccedil;e [tr]',
 '0_liste' => 'spip-dev@rezo.net',
-'0_mainteneur' => 'ender.ustungel@sj.k12.tr',
+'0_mainteneur' => 'admin@inceden.net',
 
 // A
 'access_interface_graphique' => 'Tam grafik aray&uuml;ze geri d&ouml;n',
@@ -568,7 +568,7 @@ Kat&#305;l&#305;m&#305;n&#305;z i&ccedil;in te&#351;ekk&uuml;rler
 'info_visites' => 'Ziyaret :',
 'info_vos_rendez_vous' => '&#304;lerideki randevular&#305;n&#305;z',
 'info_zoom' => 'yak&#305;nla&#351;t&#305;r',
-'infos_vos_pense_bete' => 'Hat&#305;rlatmalar&#305;n&#305;z',
+'infos_vos_pense_bete' => 'Hat&#305;rlatmalar&#305;n&#305;z', # MODIF
 'item_breve_proposee' => '&Ouml;nerilen k&#305;sa haber',
 
 // L
