@@ -549,8 +549,9 @@ function inclure_modele($type, $id, $params, $lien, $connect='') {
 	// Si un lien a ete passe en parametre, ex: [<modele1>->url]
 	if ($lien) {
 		# un eventuel guillemet (") sera reechappe par #ENV
-		$contexte['lien'] = str_replace("&quot;",'"', $lien[0]);
-		$contexte['lien_class'] = $lien[1];
+		$contexte['lien'] = str_replace("&quot;",'"', $lien['href']);
+		$contexte['lien_class'] = $lien['class'];
+		$contexte['lien_mime'] = $lien['mime'];
 	}
 
 	// Traiter les parametres
