@@ -156,7 +156,7 @@ function critere_pagination_dist($idb, &$boucles, $crit) {
 		 // tester si le numero de page demande est de la forme '@yyy'
 		 'isset($Pile[0]['.$debut.']) ? $Pile[0]['.$debut.'] : _request('.$debut.");\n"
 		."\tif(substr(\$debut_boucle,0,1)=='@'){\n"
-		."\t\t".'$debut_boucle = $Pile[0]['. $debut.'] = quete_debut_pagination(\''.$boucle->primary.'\',$Pile[0][\'@'.$boucle->primary.'\'] = substr($debut_boucle,1),'.intval($pas).',$result,'._q($boucle->sql_serveur).');'."\n"
+		."\t\t".'$debut_boucle = $Pile[0]['. $debut.'] = quete_debut_pagination(\''.$boucle->primary.'\',$Pile[0][\'@'.$boucle->primary.'\'] = substr($debut_boucle,1),'.$pas.',$result,'._q($boucle->sql_serveur).');'."\n"
 		."\t\t".'if (!sql_seek($result,0,'._q($boucle->sql_serveur).")){\n"
 		."\t\t\t".'@sql_free($result,'._q($boucle->sql_serveur).");\n"
 		."\t\t\t".'$result = calculer_select($select, $from, $type, $where, $join, $groupby, $orderby, $limit, $having, $table, $id, $connect);'."\n"
@@ -503,8 +503,12 @@ function critere_inverse_dist($idb, &$boucles, $crit) {
 		}
 
 		$n = count($boucle->order);
-		if (!$n)
+		if (!$n) {
+		  if (isset($boucle->default_order[0]))
+			$boucle->default_order[0] .=  ' . " DESC"';
+		  else
 			$boucle->default_order[] =  ' DESC';
+		}
 		else {
 			$t = $boucle->order[$n-1] . " . $order";
 			if (preg_match("/^(.*)'\s*\.\s*'([^']*')$/", $t, $r))
