@@ -421,7 +421,7 @@ function spip_pg_selectdb($db, $serveur='',$requeter=true) {
 function spip_pg_listdbs($serveur) {
 	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
 	$link = $connexion['link'];
-	return spip_pg_query($link, "select * from pg_database");
+	return spip_pg_query_simple($link, "select * From pg_database");
 }
 
 // http://doc.spip.org/@spip_pg_select
@@ -1084,7 +1084,7 @@ function spip_pg_showtable($nom_table, $serveur='',$requeter=true)
 {
 	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
 	$link = $connexion['link'];
-	$connexion['last'] = "SELECT column_name, column_default, data_type FROM information_schema.columns WHERE table_name ILIKE " . _q($nom_table);
+	$connexion['last'] = $q = "SELECT column_name, column_default, data_type FROM information_schema.columns WHERE table_name ILIKE " . _q($nom_table);
 
 	$res = spip_pg_query_simple($link, $q);
 	if (!$res) return false;
