@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -21,17 +21,21 @@ $GLOBALS['spip_sqlite3_functions_1'] = _sqlite_ref_fonctions();
 	
 	
 // http://doc.spip.org/@req_sqlite3_dist
-function req_sqlite3_dist($addr, $port, $login, $pass, $db='', $prefixe='', $ldap='') {
-	return req_sqlite_dist($addr, $port, $login, $pass, $db, $prefixe, $ldap, $sqlite_version=3);
+function req_sqlite3_dist($addr, $port, $login, $pass, $db='', $prefixe='') {
+	return req_sqlite_dist($addr, $port, $login, $pass, $db, $prefixe, $sqlite_version=3);
 }
 
 
 // http://doc.spip.org/@spip_sqlite3_constantes
 function spip_sqlite3_constantes(){
-	define('SPIP_SQLITE3_ASSOC', PDO::FETCH_ASSOC);
-	define('SPIP_SQLITE3_NUM', PDO::FETCH_NUM);
-	define('SPIP_SQLITE3_BOTH', PDO::FETCH_BOTH);
+	define('SPIP_SQLITE3_ASSOC', constant('PDO::FETCH_ASSOC'));
+	define('SPIP_SQLITE3_NUM', constant('PDO::FETCH_NUM'));
+	define('SPIP_SQLITE3_BOTH', constant('PDO::FETCH_BOTH'));
 }
 
+function spip_versions_sqlite3()
+{
+	return _sqlite_charger_version(3) ? 3 : false;
+}
 
 ?>
