@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -15,7 +15,6 @@
 // idem, il ne faut pas de $obj->toto()->toto sinon php4 se tue !
 
 # todo : get/set_caracteres ?
-# todo : REPAIR TABLE ?
 
 
 /*
@@ -25,13 +24,13 @@
  * 
  */
 // http://doc.spip.org/@req_sqlite_dist
-function req_sqlite_dist($addr, $port, $login, $pass, $db='', $prefixe='', $ldap='', $sqlite_version=''){
+function req_sqlite_dist($addr, $port, $login, $pass, $db='', $prefixe='', $sqlite_version=''){
 	static $last_connect = array();
 
 	// si provient de selectdb
 	// un code pour etre sur que l'on vient de select_db()
 	if (strpos($db, $code = '@selectdb@')!==false) {
-		foreach (array('addr','port','login','pass','prefixe','ldap') as $a){
+		foreach (array('addr','port','login','pass','prefixe') as $a){
 			$$a = $last_connect[$a];
 		}
 		$db = str_replace($code, '', $db);
@@ -64,12 +63,13 @@ function req_sqlite_dist($addr, $port, $login, $pass, $db='', $prefixe='', $ldap
 		// si installation -> base temporaire tant qu'on ne connait pas son vrai nom
 		if (defined('_ECRIRE_INSTALL') && _ECRIRE_INSTALL){
 			// creation d'une base temporaire pour le debut d'install
-			$tmp = _DIR_DB . "_sqlite".$sqlite_version."_install.sqlite";
-			if ($sqlite_version == 3)
-				$ok = $link = new PDO("sqlite:$tmp");
-			else
-				$ok = $link = sqlite_open($tmp, _SQLITE_CHMOD, $err);
 			$db = "_sqlite".$sqlite_version."_install";	
+			$tmp = _DIR_DB . $db . ".sqlite";
+			if ($sqlite_version == 3) {
+				$ok = $link = new PDO("sqlite:$tmp");
+			} else {
+				$ok = $link = sqlite_open($tmp, _SQLITE_CHMOD, $err);
+			}
 		// sinon, on arrete finalement
 		} else {
 			return false;
@@ -97,7 +97,6 @@ function req_sqlite_dist($addr, $port, $login, $pass, $db='', $prefixe='', $ldap
 			'pass' => $pass,
 			'db' => $db,
 			'prefixe' => $prefixe,
-			'ldap' => $ldap
 		);
 	}
 
@@ -105,7 +104,6 @@ function req_sqlite_dist($addr, $port, $login, $pass, $db='', $prefixe='', $ldap
 		'db' => $db,
 		'prefixe' => $prefixe ? $prefixe : $db,
 		'link' => $link,
-		'ldap' => $ldap,
 		);	
 }
 
@@ -364,6 +362,31 @@ function spip_sqlite_create($nom, $champs, $cles, $autoinc=false, $temporary=fal
 	return $ok ? true : false;
 }
 
+/**
+ * Fonction pour creer une base de donnees SQLite
+ *
+ * @param string $nom le nom de la base (sans l'extension de fichier)
+ * @param string $serveur le nom de la connexion
+ * @param string $option options
+ * 
+ * @return bool true si la base est creee.
+**/
+function spip_sqlite_create_base($nom, $serveur='', $option=true) {
+	$f = _DIR_DB . $nom . '.sqlite';
+	if (_sqlite_is_version(2, '', $serveur)) {
+		$ok = new sqlite_open($f, _SQLITE_CHMOD, $err);
+	} else {
+		$ok = new PDO("sqlite:$f");
+	}
+	if ($ok) {
+		unset($ok);
+		return true;
+	}
+	unset($ok);
+	return false;
+}
+
+
 // Fonction de creation d'une vue SQL nommee $nom
 // http://doc.spip.org/@spip_sqlite_create_view
 function spip_sqlite_create_view($nom, $query_select, $serveur='',$requeter=true) {
@@ -439,8 +462,7 @@ function spip_sqlite_countsel($from = array(), $where = array(), $groupby = '',
 	$c = !$groupby ? '*' : ('DISTINCT ' . (is_string($groupby) ? $groupby : join(',', $groupby)));
 	$r = spip_sqlite_select("COUNT($c)", $from, $where,'', '', $limit,
 			$having, $serveur, $requeter);
-	
-	if ($r && $requeter) {
+	if ((is_resource($r) or is_object($r)) && $requeter) { // ressource : sqlite2, object : sqlite3
 		if (_sqlite_is_version(3,'',$serveur)){
 			list($r) = spip_sqlite_fetch($r, SPIP_SQLITE3_NUM, $serveur);
 		} else {
@@ -525,17 +547,22 @@ function spip_sqlite_drop_index($nom, $table, $serveur='', $requeter=true) {
 	return spip_sqlite_query($query, $serveur, $requeter);
 }
 
+/**
+ * Retourne la derniere erreur generee
+ *
+ * @param $serveur nom de la connexion
+ * @return string erreur eventuelle
+**/
 // http://doc.spip.org/@spip_sqlite_error
-function spip_sqlite_error($query='', $serveur='',$requeter=true) {
+function spip_sqlite_error($serveur='') {
 	$link  = _sqlite_link($serveur);
 	
-	if (_sqlite_is_version(3, $link)){
+	if (_sqlite_is_version(3, $link)) {
 		$errs = $link->errorInfo();
 		$s = '';
 		foreach($errs as $n=>$e){
 			$s .= "\n$n : $e";
 		}
-		
 	} elseif ($link) {
 		$s = sqlite_error_string(sqlite_last_error($link));
 	} else {
@@ -545,9 +572,15 @@ function spip_sqlite_error($query='', $serveur='',$requeter=true) {
 	return $s;
 }
 
-
+/**
+ * Retourne le numero de la derniere erreur SQL
+ * (sauf que SQLite semble ne connaitre que 0 ou 1)
+ *
+ * @param $serveur nom de la connexion
+ * @return int 0 pas d'erreur / 1 une erreur
+**/
 // http://doc.spip.org/@spip_sqlite_errno
-function spip_sqlite_errno($serveur='',$requeter=true) {
+function spip_sqlite_errno($serveur='') {
 	$link  = _sqlite_link($serveur);
 	
 	if (_sqlite_is_version(3, $link)){
@@ -561,7 +594,7 @@ function spip_sqlite_errno($serveur='',$requeter=true) {
 		
 	if ($s) spip_log("Erreur sqlite $s");
 
-	return $s;
+	return $s ? 1 : 0;
 }
 
 
@@ -617,6 +650,22 @@ function spip_sqlite_fetch($r, $t='', $serveur='',$requeter=true) {
 }
 
 
+function spip_sqlite_seek($r, $row_number, $serveur='',$requeter=true) {
+	if ($r){
+		$link = _sqlite_link($serveur);
+		if (_sqlite_is_version(3, $link)){
+			// encore un truc de bien fichu : PDO ne PEUT PAS faire de seek ou de rewind...
+			// je me demande si pour sqlite 3 il ne faudrait pas mieux utiliser
+			// les nouvelles fonctions sqlite3_xx (mais encore moins presentes...)
+			return false;
+		}
+		else {
+			return sqlite_seek($r, $row_number);
+		}
+	}
+}
+
+
 // http://doc.spip.org/@spip_sqlite_free
 function spip_sqlite_free(&$r, $serveur='',$requeter=true) {
 	unset($r);
@@ -669,19 +718,21 @@ function spip_sqlite_insert($table, $champs, $valeurs, $desc='', $serveur='',$re
 	if ($prefixe) $table = preg_replace('/^spip/', $prefixe, $table);
 
 
-	$t = !isset($_GET['var_profile']) ? 0 : trace_query_start();
-
+	if (isset($_GET['var_profile'])) {
+		include_spip('public/tracer');
+		$t = trace_query_start();
+	} else $t = 0 ;
+ 
 	$query="INSERT OR REPLACE INTO $table $champs VALUES $valeurs";
-	if (!$requeter) return $query;
+	
 	
 	if ($r = spip_sqlite_query($query, $serveur)) {
+		if (!$requeter) return $query;
+		
 		if (_sqlite_is_version(3, $sqlite)) $nb = $sqlite->lastInsertId();
 		else $nb = sqlite_last_insert_rowid($sqlite);
-	} else {
-	  if ($e = spip_sqlite_errno($serveur))	// Log de l'erreur eventuelle
-		$e .= spip_sqlite_error($query, $serveur); // et du fautif
-	}
-	return $t ? trace_query_end($query, $t, $nb, $e, $serveur) : $nb;
+	} else $nb = 0;
+	return $t ? trace_query_end($query, $t, $nb, $serveur) : $nb;
 
 }
 
@@ -750,15 +801,26 @@ function spip_sqlite_multi ($objet, $lang) {
 }
 
 
+/**
+ * Optimise une table SQL
+ * Note: Sqlite optimise TOUTE un fichier sinon rien.
+ * On evite donc 2 traitements sur la meme base dans un hit.
+ * 
+ * @param $table nom de la table a optimiser
+ * @param $serveur nom de la connexion
+ * @param $requeter effectuer la requete ? sinon retourner son code
+ * @return bool|string true / false / requete
+**/
 // http://doc.spip.org/@spip_sqlite_optimize
-function spip_sqlite_optimize($table, $serveur='',$requeter=true){
-	spip_sqlite_query("OPTIMIZE TABLE ". $table, $serveur); // <- a verifier mais ca doit pas etre ca !
-	return true;
+function spip_sqlite_optimize($table, $serveur='', $requeter=true) {
+	static $do = false;
+	if ($requeter and $do) {return true;}
+	if ($requeter) { $do = true; }
+	return spip_sqlite_query("VACUUM", $serveur, $requeter);
 }
 
 
 // avoir le meme comportement que _q()
-
 function spip_sqlite_quote($v, $type=''){
 	if (is_int($v)) return strval($v);
 	if ($type === 'int' AND !$v) return '0';
@@ -777,9 +839,18 @@ function spip_sqlite_quote($v, $type=''){
 }
 
 
-// http://doc.spip.org/@spip_sqlite_repair
-function spip_sqlite_repair($table, $serveur='',$requeter=true){
-	return spip_sqlite_query("REPAIR TABLE $table", $serveur, $requeter); // <- ca m'ettonerait aussi ca !
+/**
+ * Tester si une date est proche de la valeur d'un champ
+ *
+ * @param string $champ le nom du champ a tester
+ * @param int $interval valeur de l'interval : -1, 4, ...
+ * @param string $unite utite utilisee (DAY, MONTH, YEAR, ...)
+ * @return string expression SQL
+**/
+function spip_sqlite_date_proche($champ, $interval, $unite)
+{
+	$op = $interval > 0 ? '>' : '<';
+	return "($champ $op datetime('" . date("Y-m-d H:i:s") . "', '$interval $unite'))";
 }
 
 
@@ -831,20 +902,7 @@ function spip_sqlite_select($select, $from, $where='', $groupby='', $orderby='',
 		. ($orderby ? ("\nORDER BY " . _sqlite_calculer_order($orderby)) :'')
 		. ($limit ? "\nLIMIT $limit" : '');
 
-	// Erreur ? C'est du debug de squelette, ou une erreur du serveur
-	if (isset($GLOBALS['var_mode']) AND $GLOBALS['var_mode'] == 'debug') {
-		include_spip('public/debug');
-		boucle_debug_requete($query);
-	}
-
-	if (!($res = spip_sqlite_query($query, $serveur, $requeter))) {
-		include_spip('public/debug');
-		erreur_requete_boucle(substr($query, 7),
-				      spip_sqlite_errno($serveur),
-				      spip_sqlite_error($query, $serveur) );
-	}
-
-	return $res;
+	return spip_sqlite_query($query, $serveur, $requeter);
 }
 
 
@@ -888,12 +946,7 @@ function spip_sqlite_showbase($match, $serveur='',$requeter=true){
 
 // http://doc.spip.org/@spip_sqlite_showtable
 function spip_sqlite_showtable($nom_table, $serveur='',$requeter=true){
-	// remplacer le prefixe de table
-	$connexion = $GLOBALS['connexions'][$serveur ? $serveur : 0];
-	$prefixe = $connexion['prefixe'];
-
-	if ($prefixe) $nom_table = preg_replace('/^spip/', $prefixe, $nom_table);
-		
+	
 	$query = 
 			'SELECT sql, type FROM'
    			. ' (SELECT * FROM sqlite_master UNION ALL'
@@ -945,7 +998,7 @@ function spip_sqlite_showtable($nom_table, $serveur='',$requeter=true){
 				. " AND type='index' AND name NOT LIKE 'sqlite_%'"
 				. 'ORDER BY substr(type,2,1), name';
 			$a = spip_sqlite_query($query, $serveur, $requeter);
-			while ($r = spip_sqlite_fetch($a)) {
+			while ($r = spip_sqlite_fetch($a, null, $serveur)) {
 				$key = str_replace($nom_table.'_','',$r['name']); // enlever le nom de la table ajoute a l'index
 				$colonnes = preg_replace(',.*\((.*)\).*,','$1',$r['sql']);
 				$keys['KEY '.$key] = $colonnes;
@@ -1183,7 +1236,7 @@ function _sqlite_charger_version($version=''){
 
 
 
-/*
+/**
  * Gestion des requetes ALTER non reconnues de SQLite :
  * ALTER TABLE table DROP column
  * ALTER TABLE table CHANGE [COLUMN] columnA columnB definition
@@ -1356,7 +1409,9 @@ function _sqlite_ref_fonctions(){
 		'count' => 'spip_sqlite_count',
 		'countsel' => 'spip_sqlite_countsel',
 		'create' => 'spip_sqlite_create',
+		'create_base' => 'spip_sqlite_create_base',
 		'create_view' => 'spip_sqlite_create_view',
+		'date_proche' => 'spip_sqlite_date_proche',
 		'delete' => 'spip_sqlite_delete',
 		'drop_table' => 'spip_sqlite_drop_table',
 		'drop_view' => 'spip_sqlite_drop_view',
@@ -1364,6 +1419,7 @@ function _sqlite_ref_fonctions(){
 		'error' => 'spip_sqlite_error',
 		'explain' => 'spip_sqlite_explain',
 		'fetch' => 'spip_sqlite_fetch',
+		'seek' => 'spip_sqlite_seek',
 		'free' => 'spip_sqlite_free',
 		'hex' => 'spip_sqlite_hex',
 		'in' => 'spip_sqlite_in', 
@@ -1377,7 +1433,6 @@ function _sqlite_ref_fonctions(){
 		'quote' => 'spip_sqlite_quote',
 		'replace' => 'spip_sqlite_replace',
 		'replace_multi' => 'spip_sqlite_replace_multi',
-		'repair' => 'spip_sqlite_repair',
 		'select' => 'spip_sqlite_select',
 		'selectdb' => 'spip_sqlite_selectdb',
 		'set_charset' => 'spip_sqlite_set_charset',
@@ -1584,11 +1639,21 @@ class sqlite_traiter_requete{
 	// faire le tracage si demande 
 // http://doc.spip.org/@executer_requete
 	function executer_requete(){
-		$t = $this->tracer ? trace_query_start(): 0;
+		if ($this->tracer) {
+			include_spip('public/tracer');
+			$t = trace_query_start();
+		} else $t = 0 ;
+ 
 # spip_log("requete: $this->serveur >> $this->query",'query'); // boum ? pourquoi ?
 		if ($this->link){
+			// sauver la derniere requete
+			$GLOBALS['connexions'][$this->serveur ? $this->serveur : 0]['last'] = $this->query;
+			
 			if ($this->sqlite_version == 3) {
 				$r = $this->link->query($this->query);
+				// sauvegarde de la requete (elle y est deja dans $r->queryString)
+				# $r->spipQueryString = $this->query;
+
 				// comptage : oblige de compter le nombre d'entrees retournees 
 				// par une requete SELECT
 				// aucune autre solution ne donne le nombre attendu :( !
@@ -1608,12 +1673,9 @@ class sqlite_traiter_requete{
 		} else {
 			$r = false;	
 		}
-		if (!$r && $e = spip_sqlite_errno($this->serveur))	// Log de l'erreur eventuelle
-			$e .= spip_sqlite_error($this->query, $this->serveur); // et du fautif
-	
-		return $t ? trace_query_end($this->query, $t, $r, $e, $serveur) : $r;
+
+		return $t ? trace_query_end($this->query, $t, $r, $serveur) : $r;
 	}
-	
 		
 	// transformer la requete pour sqlite 
 	// enleve les textes, transforme la requete pour quelle soit
@@ -1648,6 +1710,7 @@ class sqlite_traiter_requete{
 		}
 		
 		// Correction des dates avec INTERVAL
+		// utiliser sql_date_proche() de preference
 		if (strpos($this->query, 'INTERVAL')!==false){
 			$this->query = preg_replace_callback("/DATE_(ADD|SUB).*INTERVAL\s+(\d+)\s+([a-zA-Z]+)\)/U", 
 							array(&$this, '_remplacerDateParTime'), 
@@ -1743,7 +1806,7 @@ class sqlite_traiter_requete{
 // http://doc.spip.org/@_remplacerDateParTime
 	function _remplacerDateParTime($matches){
 		$op = strtoupper($matches[1] == 'ADD')?'+':'-';	
-		return "'".date("Y-m-d H:i:s", strtotime(" $op$matches[2] ".strtolower($matches[3])))."'";
+		return "datetime('" . date("Y-m-d H:i:s") . "', '$op$matches[2] $matches[3]')";
 	}
 
 	// callback ou l'on remplace FIELD(table,i,j,k...) par CASE WHEN table=i THEN n ... ELSE 0 END
