@@ -336,10 +336,11 @@ function urls_arbo_dist($i, $entite, $args='', $ancre='') {
 	if ($GLOBALS['profondeur_url']<=0
 	AND $_SERVER['REQUEST_METHOD'] != 'POST') {
 		include_spip('inc/urls');
-		$r = nettoyer_url_page($i, array());
+		$r = nettoyer_url_page($i, $contexte);
 		if ($r) {
 			list($contexte, $type,,, $suite) = $r;
-			list($_id,$id_objet) = each($contexte);
+			$_id = id_table_objet($type);
+			$id_objet = $contexte[$_id];
 			$url_propre = generer_url_entite($id_objet, $type);
 			if (strlen($url_propre)
 			AND !strstr($url,$url_propre)) {
