@@ -61,7 +61,6 @@ function urls_html_dist($i, $entite, $args='', $ancre='') {
 	else
 		parse_str($args,$contexte);
 
-
 	// traiter les injections du type domaine.org/spip.php/cestnimportequoi/ou/encore/plus/rubrique23
 	if ($GLOBALS['profondeur_url']>0 AND $entite=='sommaire'){
 		return array(array(),'404');
@@ -73,7 +72,10 @@ function urls_html_dist($i, $entite, $args='', $ancre='') {
 	$r = nettoyer_url_page($i, $contexte);
 	if ($r) {
 		array_pop($r); // nettoyer_url_page renvoie un argument de plus inutile ici
-		array_pop($r); // il n'est pas necessaire de forcer le fond en 4eme arg car l'url n'est pas query string
+		// il n'est pas necessaire de forcer le fond en 4eme arg car l'url n'est pas query string
+		// sauf si pas de fond connu
+		if ($entite)
+			array_pop($r); 
 		return $r;
 	}
 
