@@ -444,6 +444,8 @@ function printWordWrapped($image, $top, $left, $maxWidth, $font, $couleur, $text
 	else $lineHeight = $hauteur_ligne;
 
 	$dimensions_espace = imageftbbox($textSize, 0, $font, ' ', array());
+	if ($dimensions_espace[2] < 0)
+		$dimensions_espace = imageftbbox($textSize, 0, $font, $line, array());
 	$largeur_espace = $dimensions_espace[2] - $dimensions_espace[0];
 	$retour["espace"] = $largeur_espace;
 
@@ -623,4 +625,4 @@ function produire_image_typo() {
 }
 
 
-?>
\ No newline at end of file
+?>
