@@ -49,7 +49,13 @@ function exec_mutualisation_dist() {
 		else
 			$alias[$v] = $v;
 	}
-
+	
+	// Recuperer la liste des plugins connus de l'instance SPIP en cours (celle qui est appelee par ecrire/?exec=mutualisation)
+	include_spip('inc/plugin');
+	$liste_plug = liste_plugin_files();
+	$liste_plug_compat = liste_plugin_valides($liste_plug);
+	$liste_plug_compat = $liste_plug_compat[0];
+	
 	foreach ($sites as $v) {
 		$nom_site=$stats=$plugins=$erreur=$version_installee="";
 
@@ -76,6 +82,7 @@ function exec_mutualisation_dist() {
 			// Pour cela, on cree un bouton avec un secret, que mutualiser.php
 			// va intercepter (pas terrible ?)
 			$erreur = test_upgrade_site($meta);
+			$adminplugin = adminplugin_site($meta, $liste_plug_compat);
 			$version_installee = ' <em><small>'.$meta['version_installee'].'</small></em>';
 		}
 		else {
@@ -84,12 +91,12 @@ function exec_mutualisation_dist() {
 			$plugins = '-';
 		}
 		$page .= "<tr class='tr". $nsite % 2 ."'"
-			. " style='background-image: url(${url}spip.php?action=cron&amp;renouvelle_alea=yo);'>
+			. " style='background-image: url(${url}ecrire/index.php?exec=mutualisation&amp;renouvelle_alea=yo)'>
 			<td style='text-align:right;'>$v$erreur$version_installee</td>
 			<td><a href='${url}'>".typo($nom_site)."</a></td>
 			<td><a href='${url}ecrire/'>ecrire</a></td>
 			<td style='text-align:right;'><a href='${url}ecrire/index.php?exec=statistiques_visites'>${stats}</a></td>
-			<td><a href='${url}ecrire/index.php?exec=admin_plugin'>${cntplugins}</a> <small>${plugins}</small></td>
+			<td>$adminplugin<a href='${url}ecrire/index.php?exec=admin_plugin'>${cntplugins}</a> <small>${plugins}</small></td>
 			<td style='text-align:right;'>".date_creation_repertoire_site($v)."</td>
 			</tr>\n";
 		$nsite++;
@@ -159,7 +166,7 @@ function exec_mutualisation_dist() {
 function test_upgrade_site($meta) {
 	if ($GLOBALS['spip_version_base']
 	!= str_replace(',','.',$meta['version_installee'])) {
-		$secret = $meta['version_installee'].'-'.$meta['alea_ephemere'];
+		$secret = $meta['version_installee'].'-'.$meta['popularite_total'];
 		$secret = md5($secret);
 		return <<<EOF
 <form action='$meta[adresse_site]/ecrire/index.php?exec=mutualisation' method='post' class='upgrade' target='_blank'>
@@ -174,6 +181,33 @@ EOF;
 	}
 }
 
+function adminplugin_site($meta, $liste_plug_compat) {
+	if ($cfg = @unserialize($meta['plugin'])) {
+		$plugins = array_keys($cfg);
+		ksort($plugins);
+		foreach ($plugins as $plugin) {
+			if ($cfg[$plugin]['version'] != $liste_plug_compat[$plugin]['version']
+			AND !is_null($liste_plug_compat[$plugin]['version'])) {
+				$secret = $meta['version_installee'].'-'.$meta['popularite_total'];
+				$secret = md5($secret);
+				$vplugin = $cfg[$plugin]['version'] . '&rarr;' . $liste_plug_compat[$plugin]['version'];
+				return <<<EOF
+<form action='$meta[adresse_site]/ecrire/index.php?exec=mutualisation' method='post' class='upgrade' target='_blank'>
+<div>
+<input type='hidden' name='secret' value='$secret' />
+<input type='hidden' name='exec' value='mutualisation' />
+<input type='hidden' name='upgradeplugins' value='oui' />
+<input type='submit' value='Upgrade plugins ($plugin $vplugin)' />
+</div>
+</form>
+EOF;
+			}
+		}
+	} 
+	return '';
+}
+
+
 function date_creation_repertoire_site ($v) {
 	return (date("d/M/y", @filectime('../'.$GLOBALS['mutualisation_dir'].'/'.$v."/config/connect.php"))) ;	
 }
@@ -209,4 +243,4 @@ function mutualisation_lister_sites() {
 	return $sites;
 }
 */
-?>
+?>
\ No newline at end of file
