@@ -187,26 +187,11 @@ function demarrer_site($site = '', $options = array()) {
 		($e . _NOM_TEMPORAIRES_ACCESSIBLES)
 	);	
 
-
 	/*
-	 * Ajouter le chemin vers l'exec=mutualisation pour le site maitre
-	 * et seulement pour lui (pour en mettre plusieurs, les separer par
-	 * des virgules).
+	 *Traiter l'exec=mutualisation
 	 */
-	if (_request('exec') === 'mutualisation') {
-		if (!defined('_SITES_ADMIN_MUTUALISATION')
-		OR in_array($site, explode(',',_SITES_ADMIN_MUTUALISATION)))
-			require_once dirname(__FILE__).'/exec/mutualisation.php';
+	mutualisation_traiter_exec($site) ;
 
-		// Si un upgrade est demande dans le site fils, et securise par md5
-		// depuis le panneau de controle, le faire directement
-		if (_request('upgrade') == 'oui') {
-			require_once dirname(__FILE__).'/mutualiser_upgrade.php';
-			mutualiser_upgrade();
-		}
-	}
-	
-	
 	/*
 	 * Gestion des url d'images courtes
 	 * sites/nom/IMG/image.jpg -> IMG/image.jpg
@@ -228,6 +213,39 @@ function demarrer_site($site = '', $options = array()) {
 	}
 }
 
+
+// Ajouter le chemin vers l'exec=mutualisation pour le site maitre
+// et seulement pour lui (pour en mettre plusieurs, les separer par
+// des virgules) Voit le fichier mes_options.php
+function mutualisation_traiter_exec($site) {
+	if (_request('exec') === 'mutualisation') {
+		if (!defined('_SITES_ADMIN_MUTUALISATION')
+		OR in_array($site, explode(',',_SITES_ADMIN_MUTUALISATION)))
+			require_once dirname(__FILE__).'/exec/mutualisation.php';
+
+		// Si un upgrade est demande dans le site fils, et securise par md5
+		// depuis le panneau de controle, le faire directement
+		if (_request('upgrade') == 'oui') {
+			require_once dirname(__FILE__).'/mutualiser_upgrade.php';
+			mutualiser_upgrade();
+		}
+		// Si un upgrade des plugins est demande dans le site fils, et securise par md5
+		// depuis le panneau de controle, le faire directement
+		if (_request('upgradeplugins') == 'oui') {
+			require_once dirname(__FILE__).'/mutualiser_upgradeplugins.php';
+			mutualiser_upgradeplugins();
+		}
+		if (_request('renouvelle_alea') == 'yo') {
+		    include_spip('inc/headers');
+		    http_status(204); // No Content
+		    header("Connection: close");
+		    include_spip('inc/acces');
+		    renouvelle_alea();
+		    die;
+		}
+	}
+}
+
 // transformer les sites/truc/IMG/rtf/chose.rtf en /IMG/...
 function mutualisation_url_img_courtes($flux) {
 	if (strpos($flux, _DIR_IMG)
