@@ -24,18 +24,19 @@ function message_oubli($email, $param)
 	$r = formulaires_oubli_mail($email);
 	if (is_array($r) AND $r[1]) {
 		include_spip('inc/acces'); # pour creer_uniqid
+		include_spip('inc/texte'); # pour corriger_typo
 		$cookie = creer_uniqid();
 		sql_updateq("spip_auteurs", array("cookie_oubli" => $cookie), "id_auteur=" . $r[1]['id_auteur']);
-	
-		$nom = $GLOBALS['meta']["nom_site"];
+
+		$nom = textebrut(corriger_typo($GLOBALS['meta']["nom_site"]));
 		$envoyer_mail = charger_fonction('envoyer_mail','inc');
-	
+
 		if ($envoyer_mail($email,
 				  ("[$nom] " .  _T('pass_oubli_mot')),
 				  _T('pass_mail_passcookie',
 				     array('nom_site_spip' => $nom,
 					   'adresse_site' => url_de_base(),
-					   'sendcookie' => generer_url_public('spip_pass', 
+					   'sendcookie' => generer_url_public('spip_pass',
 					   "$param=$cookie", true)))) )
 		  return _T('pass_recevoir_mail');
 		else
@@ -52,12 +53,12 @@ function formulaires_oubli_traiter_dist(){
 }
 
 
-// fonction qu'on peut redefinir pour filtrer les adresses mail 
+// fonction qu'on peut redefinir pour filtrer les adresses mail
 // http://doc.spip.org/@test_oubli
 function test_oubli_dist($email)
 {
 	include_spip('inc/filtres'); # pour email_valide()
-	if (!email_valide($email) ) 
+	if (!email_valide($email) )
 		return _T('pass_erreur_non_valide', array('email_oubli' => htmlspecialchars($email)));
 	return array('mail' => $email);
 }
@@ -72,9 +73,9 @@ function formulaires_oubli_verifier_dist(){
 	if (!is_array($r))
 		$erreurs['oubli'] = $r;
 	else {
-		if (!$r[1]) 
+		if (!$r[1])
 			$erreurs['oubli'] = _T('pass_erreur_non_enregistre', array('email_oubli' => htmlspecialchars($email)));
-	
+
 		elseif ($r[1]['statut'] == '5poubelle' OR $r[1]['pass'] == '')
 			$erreurs['oubli'] =  _T('pass_erreur_acces_refuse');
 	}
@@ -86,7 +87,7 @@ function formulaires_oubli_mail($email)
 {
 	if (function_exists('test_oubli'))
 		$f = 'test_oubli';
-	else 
+	else
 		$f = 'test_oubli_dist';
 	$declaration = $f($email);
 
